<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Rap2hpoutre\FastExcel\FastExcel;
use DB;
use App\Models\BankAccount;
use Validator;
use App\Models\BankStatement;
use Yajra\DataTables\Facades\DataTables;

class BankStatementController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
      $bankAccount = BankAccount::select('id', DB::raw("CONCAT(title,' ',IFNULL(account_no,'')) AS title1"))->get()->pluck('title1','id')->prepend(trans('global.pleaseSelect'),'');
      if ($request->ajax()) {
          $start =  date('Y-m-d', strtotime(strtr($request->min, '/', '-')));
          $end = date('Y-m-d', strtotime(strtr($request->max, '/', '-')));
          $query = BankStatement::query()->where('bank_account_id',$request->id);
          if($request->min != null || $request->max != null ){
              $query = $query->whereDate('date','>=',date('Y-m-d',strtotime($start)))->whereDate('date','<=',date('Y-m-d',strtotime($end)));
          }
          $table = Datatables::of($query);
          $table->addColumn('placeholder', '&nbsp;');
          // $table->addColumn('actions', '&nbsp;');

          // $table->editColumn('actions', function ($row) {
          //     // $viewGate = 'bank_account_show';
          //     // $editGate = 'bank_account_edit';
          //     // $deleteGate = 'bank_account_delete';
          //     $viewGate = 'fuel_show';
          //     $editGate = 'fuel_edit';
          //     $deleteGate = 'fuel_delete';

          //     $crudRoutePart = 'bank-accounts';

          //     return view('partials.datatablesActions', compact(
          //     'viewGate',
          //     'editGate',
          //     'deleteGate',
          //     'crudRoutePart',
          //     'row'
          // ));
          // });
         $table->addColumn('cheque_number',function($row){
              return $row->cheque_number."<br> Ref: ".$row->reference;
          });
          $table->editColumn('date',function($row){
              return date('d/m/Y',strtotime($row->date));
          });
          $table->rawColumns(['actions', 'placeholder','cheque_number']);

          return $table->make(true);
      }
      return view('admin.bankstatement.index',compact('bankAccount'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create(Request $request)
    {
      $id = $request->id;
      return view('admin.bankstatement.create',compact('id'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        // dd($request->input());
        $request->validate([
            'date' => 'required',
            'amount' => 'required|numeric',
            'balance' => 'required|numeric',
            'description'=> 'nullable',
        ]);

        $input = $request->all();
        BankStatement::create($input);
        toastr()->success('Bank Statement is created successfully!');
        return redirect()->route('admin.bank-statements.index');
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\BankStatement  $bankStatement
     * @return \Illuminate\Http\Response
     */
    public function show(BankStatement $bankStatement)
    {
        return view('admin.bankstatement.show',compact('bankStatement'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\BankStatement  $bankStatement
     * @return \Illuminate\Http\Response
     */
    public function edit(BankStatement $bankStatement)
    {
        return view('admin.bankstatement.edit',compact('bankStatement'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\BankStatement  $bankStatement
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, BankStatement $bankStatement)
    {
        $request->validate([
            'date' => 'required',
            'amount' => 'required|numeric',
            'balance' => 'required|numeric',
            'description'=> 'nullable',
        ]);
        $input = $request->all();
        $bankStatement->update($input);
        toastr()->info('Bank Statement is updated successfully!');
        return redirect()->route('admin.bank-statements.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\BankStatement  $bankStatement
     * @return \Illuminate\Http\Response
     */
    public function destroy(BankStatement $bankStatement)
    {
        // if(isset($bankStatement->cashExpense) && count($bankStatement->cashExpense) > 0){
        //     toastr()->error('Bank has associated data. Please delete it first!');
        //     return back();
        // }
        $bankStatement->delete();
        toastr()->error('Bank statement has been deleted!');
        return back();
    }

    public function massDestroy(Request $request)
    {
        $request->validate([
            'ids'   => 'required|array',
        ]);
        BankStatement::whereIn('id', request('ids'))->delete();

        toastr()->error('Bank statement has been deleted!');
        return response(null, Response::HTTP_NO_CONTENT);
    }
    public function import_csv(Request $request)
    {
      $validator = Validator::make(
          [
              'file' => $request->file,
              'extension' => strtolower($request->file->getClientOriginalExtension()),
          ],
          [
              'file' => 'required',
              'extension' => 'required|in:xlsx,xls,csv',
          ]
      );
      
      if ($validator->fails()) {
          return back()->withErrors('Invalid file !');
      }
      
      if (!is_dir('../public/excel')) {
          mkdir('../public/excel');
      }
      
      $fileName = time() . '.' . $request->file->getClientOriginalExtension();
      
      $request->file->move('../public/excel', $fileName);

      ini_set('max_execution_time', 0);
      ini_set('memory_limit', -1);

      $productfile = (new FastExcel)->import(public_path() . '/excel/' . $fileName);
      
       if (count($productfile) > 0) {
          foreach ($productfile as $key => $line) { 
              BankStatement::create([
                  'bank_account_id' => $request->bank_account_id,
                  'date' => date('Y-m-d',strtotime($line['Date'])),
                  'service_fee' => $line['SERVICE FEE'],
                  'amount' => $line['Amount'],
                  'reference' => $line['REFERENCE'],
                  'cheque_number' => $line['CHEQUE NUMBER'],
                  'balance' => $line['Balance'],
                  'description' => $line['DESCRIPTION'],
                  'status' => 0,
              ]);
              
          }
          
          toastr()->success('Import Done !');
          return back();
       }
      toastr()->error('Error!');
      return back();
    }
}
