<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\AllCountry;
use App\Models\Country;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;

class CountryController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function __construct()
    {
        // $this->middleware('permission:location-list', ['only' => ['index']]);
        // $this->middleware('permission:location-create', ['only' => ['create', 'store']]);
        // $this->middleware('permission:location-edit', ['only' => ['edit', 'update']]);
        // $this->middleware('permission:location-delete', ['only' => ['destroy', 'bulk_delete']]);
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $all_countries = Country::all();
        foreach ($all_countries as $cun) {
            $iso3         = $cun->country;
            $country_name = AllCountry::where('iso3', $iso3)->orderBy('id', 'DESC')->get();
        }
        return view('admin.Location.country', compact('all_countries'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $all_countries = Country::all();
        return view('admin.location.country', compact('all_countries'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $data = $this->validate($request, [
            'country' => 'required|unique:countries|min:3|max:3',
        ]);

        $input            = $request->all();
        $input['country'] = strtoupper($input['country']);

        $exist = AllCountry::where('iso3', $request->country)->first();
        if ($exist != null) {
            $value = Country::create($input);
        }
        if (isset($value)) {
             toastr()->success('Country Has Been Added!');
            return back()->with("message","Country Has Been Added !");
        } else {
             toastr()->error('Please enter a valid code!');
            return back()->with("error","Please enter a valid code");
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Modules\Location\Models\Country  $country
     * @return \Illuminate\Http\Response
     */
    public function show(Country $country)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Modules\Location\Models\Country  $country
     * @return \Illuminate\Http\Response
     */
    public function edit(Country $country)
    {
        $all_countries = Country::all();
        return view('admin.location.country', compact('all_countries', 'country'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Modules\Location\Models\Country  $country
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Country $country)
    {
        $data = $this->validate($request, [
            "country" => 'required|min:3|max:3|unique:countries,country,' . $country->id,
        ]);
        $input            = $request->all();
        $input['country'] = strtoupper($input['country']);
        $exist            = AllCountry::where('iso3', $request->country)->first();
        if ($exist != null) {
            $value = $country->update($input);
        }
        if ($value) {

             toastr()->info('Country Has Been updated!');
            return redirect("admin/country")->with("message","Country Has Been Updated");
        } else {
             toastr()->error('Please enter a valid code!');
            return back()->with("error","Please enter a valid code");
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Modules\Location\Models\Country  $country
     * @return \Illuminate\Http\Response
     */
    public function destroy(Country $country)
    {
        try {
            $value = $country->delete();
        } catch (\Illuminate\Database\QueryException $e) {
            if ($e->errorInfo[1] == 1451) {
                toastr()->error('Can\'t delete as country is linked to others.');
                return back()->with("error",'Can\'t delete as country is linked to parents.');
            } else {
                toastr()->error('Can\'t delete as country is linked to others.');
                return back()->with("error",'Can\'t delete this object.');
            }
        }
        if ($value) {
            return back()->with('error', 'Country has been deleted');
        }
    }
    public function bulk_delete(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'checked' => 'required',
        ]);
        if ($validator->fails()) {
            toastr()->error('Please select one of them to delete');
            return back()->with('error', 'Please select one of them to delete');
        }
        foreach ($request->checked as $checked) {
            $this->destroy($checked);
        }
        toastr()->error('Country has been deleted');
        return back()->with('error', 'Country has been deleted');
    }
}
