<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\BankAccount;
use App\Models\Deposit;
use App\Models\FinancialCategory;
use App\Models\BankStatement;
use App\Models\DrivewaySheet;
use Illuminate\Http\Request;
use DB;
use SebastianBergmann\CodeCoverage\Report\Xml\Totals;
use Symfony\Component\HttpFoundation\Response;
use Yajra\DataTables\Facades\DataTables;
use Gate;

class DepositController extends Controller
{
    public function __construct()
    {
        $this->middleware(function ($request, $next) {
            $this->branch_id = session()->get('branch_id');
            return $next($request);
        });

    }

    public $driveway_sheet_approval = null;
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        abort_if(Gate::denies('deposit_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');
        $bankdata = BankStatement::where('description','LIKE',"%Deposit%")->select('id', 'status', 'bank_account_id',DB::raw("CONCAT(description,' [id: ',id,',Amount: ',amount,',Date:  ',date,']') AS name"))->get();
        $date =  $request->date;
        if ($request->ajax()) {
            $start =  date('Y-m-d', strtotime(strtr($request->min, '/', '-')));
            $end = date('Y-m-d', strtotime(strtr($request->max, '/', '-')));
            $query = Deposit::query()->where('branch_id',$this->branch_id);
            $dw_sheet = DrivewaySheet::query()->where('branch_id',$this->branch_id);
            if($request->date != null ){
                $query = $query->whereDate('date',$date);
                $this->driveway_sheet_approval = $dw_sheet->whereDate('date',$date);
            }
            if($request->min != null || $request->max != null ){
                $query = $query->whereDate('date','>=',date('Y-m-d',strtotime($start)))->whereDate('date','<=',date('Y-m-d',strtotime($end)));
            }
            $table = DataTables::of($query);
            $table->addIndexColumn();

            $table->addColumn('placeholder', '&nbsp;');
            $table->addColumn('actions', '&nbsp;');
            $table->addColumn('date',function($row){
               $data  = $row->date ? date('d/m/Y',strtotime($row->date)) : '';
               $data  .= $row->deposit_date != null ? '<br> Deposit: '.date('d/m/Y',strtotime($row->deposit_date)) : '';
               $data .= $row->status == 1 ? '<br><span class="badge bg-inverse-success">Approved</span>' : '<br><span class="badge bg-inverse-danger">Not Approved</span>';
               return $data;
            });

            $table->addColumn('sub_category',function($row){
                $data  =  $row->financialCategory ? $row->financialCategory->header->header_name.' > <br>'.$row->financialCategory->title : '';
                $data  .= $row->is_cancel == 1 ? '<br><span class="badge bg-inverse-danger">Cancelled</span>' : '';
                return $data;
            });

            $table->addColumn('bank_account',function($row){
                $data = $row->bankAccount ? $row->bankAccount->title : '';
                $data .= '<input type="hidden" value='.$row->id.' class="depositrow">';
                return $data;
            });
            if(Gate::allows('deposit_bank_statement')){
                $table->addColumn('bank_statement_id', function ($row) use ($bankdata) {
                    // return $row->bank_statement_id;
                    $bankstatement = $bankdata->where('bank_account_id',$row->bank_account_id);
                    $options = '<option value="">Please Select</option>';
                    // here we prepare the options
                    foreach ($bankstatement as $bank) {
                        if($bank->status == "0"){
                            $options .= '<option value="'.$bank->id.'">'.$bank->name.'</option>';
                        }
                        if($row->bank_statement_id == $bank->id){
                            $options .= '<option value="'.$bank->id.'" selected>'.$bank->name.'</option>';
                        }
                    }

                    $return =
                        '<div class="form-group">
                            <select class="form-control select-bank">' . $options . '</select>
                        </div>';

                    return $return;
                });
            }
            $table->editColumn('actions', function ($row) {
                $dw_sheet_first = $this->driveway_sheet_approval != null ? $this->driveway_sheet_approval->first() : DrivewaySheet::whereDate('date',$row->date)->first();
                $is_approve = 0;
                if ($dw_sheet_first != null) {
                    $is_approve = $dw_sheet_first->is_approved;
                }
                $viewGate = 'deposit_show';
                $is_approve == 0 ? $editGate = 'deposit_edit' : $editGate = '';
                $is_approve == 0 ? $deleteGate = 'deposit_delete' : $deleteGate = '';
                $crudRoutePart = 'deposits';

                return view('partials.datatablesActions', compact(
                'viewGate',
                'editGate',
                'deleteGate',
                'crudRoutePart',
                'row'
            ));
            });

            $table->rawColumns(['actions', 'placeholder', 'header','bank_account','date','bank_statement_id','sub_category']);
            return $table->make(true);
        }
        return view('admin.deposit.index',compact('bankdata','date'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create(Request $request)
    {
        abort_if(Gate::denies('deposit_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');
        $date =  $request->date;
        $subCategory = FinancialCategory::with('header')
                            ->whereHas('header', function($query) {
                                $query->where('category_type','deposit');})
                            ->where('status','1')->pluck('title','id')->prepend(trans('global.pleaseSelect'),'');
        $bankAccount = BankAccount::select('id', DB::raw("CONCAT(title,' ',IFNULL(account_no,'')) AS title1"))->get()->pluck('title1','id')->prepend(trans('global.pleaseSelect'),'');
        $pdpays = Deposit::where('branch_id',$this->branch_id)->where('sub_category_id','51')->where('status','0')->whereNull('is_cancel')->pluck('detail','id');
        return view('admin.deposit.create',compact('subCategory','bankAccount','pdpays','date'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        abort_if(Gate::denies('deposit_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $request->validate([
            'date' => 'required',
            'sub_category.*' => 'required|integer',
            'amount.*' => 'required|numeric',
            'bank_account.*' => 'nullable|integer',
            'detail.*' => 'nullable|string',
        ],[
            'sub_category.*.required' => 'The sub-category field is required.',
            'amount.*.required' => 'The amount field is required.',
            'amount.*.numeric' => 'The amount must be a number.',
        ]);

        if ($request->ajax()) {

            foreach ($request->sub_category as $key => $value) {
                $detail = null;
                $bankAccount = null;
                $req_date = strtr($request->date,'/','-');
                $date = date('Y-m-d',strtotime($req_date));
                if ($request->has('bank_account') && ($request->bank_account != null)) {
                    foreach ($request->bank_account as $id => $val) {
                        if ($key == $id && $val != null) {
                            $bankAccount = $request->bank_account[$key];
                        }
                    }
                }
                if ($request->has('detail') && ($request->detail != null)) {
                    foreach ($request->detail as $id => $val) {
                        if ($key == $id && $val != null) {
                            $detail = $request->detail[$key];
                        }
                    }
                }
                $checked = isset($request->type[$key]) &&  $request->sub_category[$key] == "33" ? 'pd' : (isset($request->type[$key]) &&  $request->sub_category[$key] == "45" ? 'eft' : null);
                $dd = strtr($request->deposit_date[$key],'/','-');
                $depositdate = $request->deposit_date[$key] != null ? date('Y-m-d',strtotime($dd)) : null;
                Deposit::create([
                    'date' => $date,
                    'sub_category_id' => $request->sub_category[$key],
                    'amount' => $request->amount[$key],
                    'bank_account_id' => $bankAccount,
                    'detail' => $detail,
                    'branch_id' => $this->branch_id,
                    'deposit_date' => $depositdate,
                    'ref_id' => $request->ref_id[$key],
                ]);
                Deposit::where('id',$request->ref_id[$key])->update(['is_cancel' => '1']);
            }
        }
        return response()->json(['success'=>true,'message'=>'Deposit added successfully!','url'=> url('admin/deposits?date='.$date)]);
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show(Deposit $deposit)
    {
        abort_if(Gate::denies('deposit_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.deposit.show',compact('deposit'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(Deposit $deposit)
    {
        abort_if(Gate::denies('deposit_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');
        $driveway_sheet = DrivewaySheet::query()->where('branch_id',$this->branch_id)->whereDate('date',$deposit->date);
        if ($driveway_sheet != null) {
            if($driveway_sheet->first()->is_approved)
            {
                toastr()->error('Deposit can\'t be edit!');
                return redirect()->route('admin.driveway-sheets.index');
            }
        }

        $subCategory = FinancialCategory::with('header')
                            ->whereHas('header', function($query) {
                                $query->where('category_type','deposit');})
                            ->where('status','1')->pluck('title','id')->prepend(trans('global.pleaseSelect'),'');
        $bankAccount = BankAccount::select('id', DB::raw("CONCAT(title,' ',IFNULL(account_no,'')) AS title1"))->get()->pluck('title1','id')->prepend(trans('global.pleaseSelect'),'');
        $pdpays = Deposit::where('branch_id',$this->branch_id)->where('sub_category_id','51')->where('status','0')->whereNull('is_cancel')->pluck('detail','id');
        $currentpd = Deposit::where('id',$deposit->ref_id)->first();
        return view('admin.deposit.edit',compact('deposit','subCategory','bankAccount','pdpays','currentpd'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Deposit $deposit)
    {
        abort_if(Gate::denies('deposit_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');
        $driveway_sheet = DrivewaySheet::query()->where('branch_id',$this->branch_id)->whereDate('date',$deposit->date);
        if ($driveway_sheet != null) {
            if($driveway_sheet->first()->is_approved)
            {
                toastr()->error('Deposit can\'t be edit!');
                return redirect()->route('admin.driveway-sheets.index');
            }
        }

        $request->validate([
            'date' => 'required',
            'sub_category' => 'required|integer',
            'amount' => 'required|numeric',
            'bank_account' => 'nullable|integer',
            'detail' => 'nullable|string',
        ]);
        $detail = $request->detail? $request->detail:null;
        $bankAccount = $request->bank_account? $request->bank_account : null;
        $req_date = strtr($request->date,'/','-');
        $date = date('Y-m-d',strtotime($req_date));
        $checked = isset($request->type) &&  $request->sub_category == "33" ? 'pd' : (isset($request->type) &&  $request->sub_category == "45" ? 'eft' : null);
        $dd = strtr($request->deposit_date,'/','-');
        $depositdate = $request->deposit_date != null ? date('Y-m-d',strtotime($dd)) : null;

        //update cancel status of old reference id
        if($request->ref_id != $deposit->ref_id){
            Deposit::where('id',$deposit->ref_id)->update(['is_cancel' => null]);
            if($request->ref_id != null){
                Deposit::where('id',$request->ref_id)->update(['is_cancel' => '1']);
            }
        }

        //update deposit
        $deposit->update([
            'date' => $date,
            'sub_category_id' => $request->sub_category,
            'amount' => $request->amount,
            'bank_account_id' => $bankAccount,
            'detail' => $detail,
            'branch_id' => $this->branch_id,
            'type' => $checked,
            'deposit_date' => $depositdate,
            'ref_id' => $request->ref_id,
        ]);
        toastr()->info('Deposit has be updated successfully!');
        return redirect('admin/deposits?date='.$date);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Deposit $deposit)
    {
        abort_if(Gate::denies('deposit_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');
        $driveway_sheet = DrivewaySheet::query()->where('branch_id',$this->branch_id)->whereDate('date',$deposit->date);
        if ($driveway_sheet != null) {
            if($driveway_sheet->first()->is_approved)
            {
                toastr()->error('Deposit can\'t be delete!');
                return redirect()->route('admin.driveway-sheets.index');
            }
        }

        $deposit->forceDelete();
        toastr()->error('Deposit has been deleted!');
        return redirect('admin/deposits?date='.$deposit->date);
    }

    public function massDestroy(Request $request)
    {
        abort_if(Gate::denies('deposit_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');
        $request->validate([
            'ids'   => 'required|array',
            'ids.*' => 'exists:deposits,id',
        ]);

        foreach($request->ids as $id){
            $deposit = Deposit::find($id);
            $this->destroy($deposit);
        }
        // toastr()->error('Deposit has been deleted!');
        return response(null, Response::HTTP_NO_CONTENT);
    }

    public function update_bankstatement(Request $request)
    {
        abort_if(Gate::denies('deposit_bank_statement'), Response::HTTP_FORBIDDEN, '403 Forbidden');

         $status = 1;
        $deposit = Deposit::find($request->rowid);
        if($request->paymentid == null){
            $status = '0';
        }
        else{
            $exist = Deposit::where('branch_id',$this->branch_id)->where('bank_statement_id',$request->paymentid)->where('id',"!=",$deposit->id)->first();
            if(!empty($exist)){
                return response()->json(['status'=> 'error','message' => 'Payment is already assigned to other deposit']);
            }
        }
        $depositupdate = $deposit->update([
            'bank_statement_id' => $request->paymentid,
            'status' => $status,
        ]);
        $statement = BankStatement::where('id',$request->paymentid)->update(['status' => $status]);
        return response()->json('1',200);
    }
}
