<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\MassDestroyFuelRequest;
use App\Http\Requests\StoreFuelRequest;
use App\Http\Requests\UpdateFuelRequest;
use App\Models\Fuel;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;
use Gate;
use Yajra\DataTables\Facades\DataTables;

class FuelController extends Controller
{
   /**
     * Display a listing of the resource.
     *
     * @return Symfony\Component\HttpFoundation\Response
     */
    public function index(Request $request)
    {
        abort_if(Gate::denies('fuel_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        if ($request->ajax()) {
            $query = Fuel::all();
            $table = DataTables::of($query);
            $table->addIndexColumn();

            $table->addColumn('DT_RowId', function ($row) {
                return $row->id ? $row->id : '';
            });
            $table->addColumn('placeholder', '&nbsp;');
            $table->addColumn('actions', '&nbsp;');

            $table->editColumn('actions', function ($row) {
                $viewGate = 'fuel_show';
                $editGate = 'fuel_edit';
                $deleteGate = 'fuel_delete';
                $crudRoutePart = 'fuels';

                return view('partials.datatablesActions', compact(
                'viewGate',
                'editGate',
                'deleteGate',
                'crudRoutePart',
                'row'
            ));
            });

            $table->editColumn('fuel_name', function ($row) {
                return $row->fuel_name ? $row->fuel_name : '';
            });

            $table->editColumn('price', function ($row) {
                return $row->price ? $row->price : '';
            });

            $table->rawColumns(['actions', 'placeholder', 'suplier']);

            return $table->make(true);
        }

        return view('admin.fuels.index');

    }

    /**
     * Show the form for creating a new resource.
     *
     * @return Symfony\Component\HttpFoundation\Response
     */
    public function create()
    {
        abort_if(Gate::denies('fuel_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.fuels.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  mixed $request
     * @return Symfony\Component\HttpFoundation\Response
     */
    public function store(StoreFuelRequest $request)
    {
        $fuel = Fuel::create($request->all());
        toastr()->success('Fuel is created successfully!');
        return redirect()->route('admin.fuels.index');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return Symfony\Component\HttpFoundation\Response
     */
    public function show(Fuel $fuel)
    {
        abort_if(Gate::denies('fuel_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.fuels.show', compact('fuel'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return Symfony\Component\HttpFoundation\Response
     */
    public function edit(Fuel $fuel)
    {
        abort_if(Gate::denies('fuel_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.fuels.edit', compact('fuel'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  mixed $request
     * @param  int  $id
     * @return Symfony\Component\HttpFoundation\Response
     */
    public function update(UpdateFuelRequest $request, Fuel $fuel)
    {
        $input = $request->all();
        $request->has('is_shell') ? $input['is_shell'] = 1 : $input['is_shell'] = 0 ;
        $fuel->update($input);
        toastr()->info('Fuel has been updated successfully!');
        return redirect()->route('admin.fuels.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return Symfony\Component\HttpFoundation\Response
     */
    public function destroy(Fuel $fuel)
    {
        abort_if(Gate::denies('fuel_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');
        if(isset($fuel->drivewaysheet) && count($fuel->drivewaysheet) > 0){
            toastr()->error('It has associated data. Please delete that first!');
            return back();
        }
        $fuel->forceDelete();
        toastr()->error('Fuel has been deleted!');
        return back();
    }
    /**
     * massDestroy
     *
     * @param  mixed $request
     * @return void
     */
    public function massDestroy(MassDestroyFuelRequest $request)
    {
        $request->validate([
            'ids'   => 'required|array',
        ]);
        foreach($request->ids as $id){
            $fuel = Fuel::find($id);
            $this->destroy($fuel);
        }
        // Fuel::whereIn('id', request('ids'))->delete();

        // toastr()->error('Fuel has been deleted!');
        return response(null, Response::HTTP_NO_CONTENT);
    }
}
