<?php

namespace App\Http\Controllers\Admin;

use App\Models\CashExpense;
use App\Models\Deposit;
use App\Models\Fuel;
use App\Models\Header;
use App\Models\Pump;
use App\Models\Sale;
use App\Models\User;
use Carbon\Carbon;
use Gate;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Session;
use LaravelDaily\LaravelCharts\Classes\LaravelChart;
use Symfony\Component\HttpFoundation\Response;

class HomeController
{
    public function index()
    {

        $date = Carbon::today();
        $prev_month = date('m',strtotime('first day of last month'));

        $sale_query = Sale::query()->with('financialCategory.header')
                        ->where('branch_id',session()->get('branch_id'));

        $chk_null = count($sale_query->get());
        $daily_sale = '';
        $l_7_date = $date->subDays(7);

        if ($chk_null) {

            $shop_sale = Sale::query()->with('financialCategory.header')
                            ->where('branch_id',session()->get('branch_id'))
                            ->whereHas('financialCategory.header',function($cat){$cat->where('code','cat3');})
                            ->whereYear('date',$date->year)->select('*',DB::raw("MONTH(date) as month"),DB::raw("sum(amount) as total_amount"))
                            ->groupBy('month')
                            ->get()
                            ->pluck('total_amount','month');


            $fuel_sale = $sale_query
                        ->whereHas('financialCategory.header',function($cat){$cat->where('code','cat26');})
                        ->whereYear('date',$date->year)->select('*',DB::raw("MONTH(date) as month"),DB::raw("sum(amount) as total_amount"))
                        ->groupBy('month')
                        ->get()
                        ->pluck('total_amount','month');

            $daily_sale = Sale::query()->where('branch_id',session()->get('branch_id'))
                        // ->whereYear('date',$date->year)
                        // ->whereMonth('date',$date->month)
                        ->where('date','>=',$l_7_date)
                        ->select('date',DB::raw("sum(amount) as total_amount"))
                        ->groupBy('date')
                        ->get()
                        ->pluck('total_amount','date');

        }


        $widgets = [
            'sales' => Sale::query()->where('branch_id',session()->get('branch_id'))->whereYear('date',$date->year)->sum('amount'),
            'deposits' => Deposit::query()->with('financialCategory.header')->where('branch_id',session()->get('branch_id'))->sum('amount'),
            'l_sale' => Sale::query()->where('branch_id',session()->get('branch_id'))->whereMonth('date',$prev_month)->sum('amount'),
            'c_sale' => Sale::query()->where('branch_id',session()->get('branch_id'))->whereMonth('date',$date->month)->sum('amount'),
            'exp' => CashExpense::query()->where('branch_id',session()->get('branch_id'))->whereYear('date',$date->year)->whereDate('date',date('Y-m-d',strtotime($date)))->get(),
            'users' => User::all()->count(),
        ];

        // $lable = [
        //     ['y' =>'January','a' => 0,'b' => 0],
        //     ['y' =>'February','a' => 0,'b' => 0],
        //     ['y' =>'March','a' => 0,'b' => 0],
        //     ['y' =>'April','a' => 0,'b' => 0],
        //     ['y' =>'May','a' => 0,'b' => 0],
        //     ['y' =>'June','a' => 0,'b' => 0],
        //     ['y' =>'July','a' => 0,'b' => 0],
        //     ['y' =>'August','a' => 0,'b' => 0],
        //     ['y' =>'September','a' => 0,'b' => 0],
        //     ['y' =>'October','a' => 0,'b' => 0],
        //     ['y' =>'November','a' => 0,'b' => 0],
        //     ['y' =>'December','a' => 0,'b' => 0]
        // ];

        $lable = [
            ['y' =>'Jan','a' => 0,'b' => 0],
            ['y' =>'Feb','a' => 0,'b' => 0],
            ['y' =>'Mar','a' => 0,'b' => 0],
            ['y' =>'Apr','a' => 0,'b' => 0],
            ['y' =>'May','a' => 0,'b' => 0],
            ['y' =>'June','a' => 0,'b' => 0],
            ['y' =>'July','a' => 0,'b' => 0],
            ['y' =>'Aug','a' => 0,'b' => 0],
            ['y' =>'Sep','a' => 0,'b' => 0],
            ['y' =>'Oct','a' => 0,'b' => 0],
            ['y' =>'Nov','a' => 0,'b' => 0],
            ['y' =>'Dec','a' => 0,'b' => 0]
        ];

        $lable_2 = [];
        for ($i=1; $i <=7 ; $i++) {
            array_push($lable_2,['y' =>date('Y-m-d',strtotime('+'. $i .'day',strtotime($l_7_date))),'a' => 0]);
        }

        $data ='';
        $data2 ='';

        if ($chk_null) {
            foreach ($shop_sale as $key => $value) {
                    $lable[$key-1]['a'] = $value;
            }

            foreach ($fuel_sale as $key => $value) {
                    $lable[$key-1]['b'] = $value;
            }

            foreach ($daily_sale as $key => $value) {
                for ($i=0; $i < 7; $i++) {
                 if($lable_2[$i]['y'] == $key)
                     $lable_2[$i]['a'] = $value;
                }
            }
        }


       $data = json_encode($lable);
       $data2 = json_encode($lable_2);


       return view('home',compact('widgets','data','data2'));
    }

    // Super Admin

    public function branch($id)
    {
        abort_if(Gate::denies('super_admin_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');
        Session::put('branch_id',$id);
        return redirect()->route('admin.home');
    }

    public function superAdminDashboard()
    {
        abort_if(Gate::denies('super_admin_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');
        $date = Carbon::today();
        $prev_month = date('m',strtotime('first day of last month'));

        $widgets = [
            'sales' => Sale::query()->whereYear('date',$date->year)->sum('amount'),
            'deposits' => Deposit::query()->sum('amount'),
            'l_sale' => Sale::query()->whereYear('date',$date->year)->whereMonth('date',$prev_month)->sum('amount'),
            'c_sale' => Sale::query()->whereYear('date',$date->year)->whereMonth('date',$date->month)->sum('amount'),
            'exp' => CashExpense::query()->whereYear('date',$date->year)->whereDate('date',date('Y-m-d',strtotime($date)))->select('*',DB::raw("sum(amount) as total_amount"))->groupBy('branch_id')->get(),
            'shop_sale' => Sale::query()->whereHas('financialCategory.header',function($cat){$cat->where('code','cat3');})->whereDate('date',date('Y-m-d',strtotime($date)))->whereYear('date',$date->year)->select('*',DB::raw("sum(amount) as total_amount"))->groupBy('branch_id')->get(),
            'fuel_sale' => Sale::query()->whereHas('financialCategory.header',function($cat){$cat->where('code','cat26');})->whereDate('date',date('Y-m-d',strtotime($date)))->whereYear('date',$date->year)->select('*',DB::raw("sum(amount) as total_amount"))->groupBy('branch_id')->get(),
            'users' => User::all()->count(),
        ];

        $sale_query = Sale::query()->with('financialCategory.header');

        $chk_null = count($sale_query->get());
        $daily_sale = '';

        if ($chk_null) {

            $shop_sale = Sale::query()->with('financialCategory.header')
                            ->whereHas('financialCategory.header',function($cat){$cat->where('code','cat3');})
                            ->whereYear('date',$date->year)->select('*',DB::raw("MONTH(date) as month"),DB::raw("sum(amount) as total_amount"))
                            ->groupBy('month')
                            ->get()
                            ->pluck('total_amount','month');


            $fuel_sale = $sale_query
                        ->whereHas('financialCategory.header',function($cat){$cat->where('code','cat26');})
                        ->whereYear('date',$date->year)->select('*',DB::raw("MONTH(date) as month"),DB::raw("sum(amount) as total_amount"))
                        ->groupBy('month')
                        ->get()
                        ->pluck('total_amount','month');
            $l_7_date = $date->subDays(7);
            $daily_sale = Sale::query()->whereYear('date',$date->year)
                        ->where('date','>=',$l_7_date)
                        ->select('date',DB::raw("sum(amount) as total_amount"))
                        ->groupBy('date')
                        ->get()
                        ->pluck('total_amount','date');
        }

        $lable = [
            ['y' =>'Jan','a' => 0,'b' => 0],
            ['y' =>'Feb','a' => 0,'b' => 0],
            ['y' =>'Mar','a' => 0,'b' => 0],
            ['y' =>'Apr','a' => 0,'b' => 0],
            ['y' =>'May','a' => 0,'b' => 0],
            ['y' =>'June','a' => 0,'b' => 0],
            ['y' =>'July','a' => 0,'b' => 0],
            ['y' =>'Aug','a' => 0,'b' => 0],
            ['y' =>'Sep','a' => 0,'b' => 0],
            ['y' =>'Oct','a' => 0,'b' => 0],
            ['y' =>'Nov','a' => 0,'b' => 0],
            ['y' =>'Dec','a' => 0,'b' => 0]
        ];

        $lable_2 = [];
        for ($i=1; $i <=7 ; $i++) {
            array_push($lable_2,['y' =>date('Y-m-d',strtotime('+'. $i .'day',strtotime($l_7_date))),'a' => 0]);
        }

        $data ='';
        $data2 ='';

        if ($chk_null) {
            foreach ($shop_sale as $key => $value) {
                    $lable[$key-1]['a'] = $value;
            }

            foreach ($fuel_sale as $key => $value) {
                    $lable[$key-1]['b'] = $value;
            }

            foreach ($daily_sale as $key => $value) {
               for ($i=0; $i < 7; $i++) {
                if($lable_2[$i]['y'] == $key)
                    $lable_2[$i]['a'] = $value;
               }
            }
        }

        // return $lable_2;

       $data = json_encode($lable);
       $data2 = json_encode($lable_2);

        return view('superAdminDashboard',compact('widgets','data','data2'));
    }
}
