<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\BankAccount;
use App\Models\DrivewaySheet;
use App\Models\FinancialCategory;
use App\Models\Sale;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;
use Yajra\DataTables\Facades\DataTables;
use Gate;

class SaleController extends Controller
{
    public function __construct()
    {
        $this->middleware(function ($request, $next) {
            $this->branch_id = session()->get('branch_id');
            return $next($request);
        });

    }

    public $driveway_sheet_approval = null;

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        abort_if(Gate::denies('sale_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');
        $date =  $request->date;
        if ($request->ajax()) {
            $start =  date('Y-m-d', strtotime(strtr($request->min, '/', '-')));
            $end = date('Y-m-d', strtotime(strtr($request->max, '/', '-')));
            $query = Sale::query()->where('branch_id',$this->branch_id);
            $dw_sheet = DrivewaySheet::query()->where('branch_id',$this->branch_id);
            if($request->date != null ){
                $query = $query->whereDate('date',$date);
                $this->driveway_sheet_approval = $dw_sheet->whereDate('date',$date);
            }
            if($request->min != null || $request->max != null ){
                $query = $query->whereDate('date','>=',date('Y-m-d',strtotime($start)))->whereDate('date','<=',date('Y-m-d',strtotime($end)));
            }
            $table = DataTables::of($query);
            $table->addIndexColumn();

            $table->addColumn('DT_RowId',function($row){
                return $row->id ? $row->id : '';
            });
            $table->addColumn('placeholder', '&nbsp;');
            $table->addColumn('actions', '&nbsp;');

            $table->editColumn('date',function($row){
                return $row->date ? date('d/m/Y',strtotime($row->date)) : '';
            });

            $table->editColumn('sub_category',function($row){
                return $row->financialCategory? $row->financialCategory->title:'';
            });

            $table->editColumn('bank_account',function($row){
                return $row->bankAccount? $row->bankAccount->title:'';
            });

            $table->editColumn('actions', function ($row) {
                $dw_sheet_first = $this->driveway_sheet_approval != null ? $this->driveway_sheet_approval->first() : DrivewaySheet::whereDate('date',$row->date)->first();
                $is_approve = 0;
                if ($dw_sheet_first != null) {
                    $is_approve = $dw_sheet_first->is_approved;
                }
                $viewGate = 'sale_show';
                $is_approve == 0 ? $editGate = 'sale_edit' : $editGate = '';
                $is_approve == 0 ? $deleteGate = 'sale_delete' : $deleteGate = '';
                $crudRoutePart = 'sales';

                return view('partials.datatablesActions', compact(
                'viewGate',
                'editGate',
                'deleteGate',
                'crudRoutePart',
                'row'
            ));
            });

            $table->rawColumns(['actions', 'placeholder', 'sale']);
            return $table->make(true);
        }
        return view('admin.sale.index',compact('date'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create(Request $request)
    {
        abort_if(Gate::denies('sale_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $date =  $request->date;
        $subCategory = FinancialCategory::with('header')
                            ->whereHas('header', function($query) {
                                $query->where('category_type','sale');})
                            ->where('status','1')->pluck('title','id')->prepend(trans('global.pleaseSelect'),'');
        $bankAccount = BankAccount::all()->pluck('title','id')->prepend(trans('global.pleaseSelect'),'');
        return view('admin.sale.create',compact('subCategory','bankAccount','date'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        abort_if(Gate::denies('sale_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $request->validate([
            'date' => 'required',
            // 'title.*' => 'required|string|max:40|unique:deposits,title',
            'sub_category.*' => 'required|integer',
            'amount.*' => 'required|numeric',
            'detail.*' => 'nullable|string',
        ],[
            'sub_category.*.required' => 'The sub-category field is required.',
            'amount.*.required' => 'The amount field is required.',
            'amount.*.numeric' => 'The amount must be a number.',
        ]);

        if ($request->ajax()) {

            foreach ($request->sub_category as $key => $value) {
                $detail = null;
                // $bankAccount = null;
                $req_date = strtr($request->date,'/','-');
                $date = date('Y-m-d',strtotime($req_date));
                if ($request->has('detail') && ($request->detail != null)) {
                    foreach ($request->detail as $id => $val) {
                        if ($key == $id && $val != null) {
                            $detail = $request->detail[$key];
                        }
                    }
                }
                Sale::create([
                    'date' => $date,
                    'sub_category_id' => $request->sub_category[$key],
                    'amount' => $request->amount[$key],
                    'detail' => $detail,
                    'branch_id' => $this->branch_id,
                ]);
            }
        }
        return response()->json(['success'=>true,'message'=>'Sale added successfully!','url'=> url('admin/sales?date='.$date)]);
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show(Sale $sale)
    {
        abort_if(Gate::denies('sale_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.sale.show',compact('sale'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(Sale $sale)
    {
        abort_if(Gate::denies('sale_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        // restrict if driveway sheet is approved on given date
        $driveway_sheet = DrivewaySheet::query()->where('branch_id',$this->branch_id)->whereDate('date',$sale->date);
        if ($driveway_sheet != null) {
            if($driveway_sheet->first()->is_approved)
            {
                toastr()->error('Sale can\'t be edit!');
                return redirect()->route('admin.driveway-sheets.index');
            }
        }

        $subCategory = FinancialCategory::with('header')
                            ->whereHas('header', function($query) {
                                $query->where('category_type','sale');})
                            ->where('status','1')->pluck('title','id')->prepend(trans('global.pleaseSelect'),'');
        $bankAccount = BankAccount::all()->pluck('title','id')->prepend(trans('global.pleaseSelect'),'');
        return view('admin.sale.edit',compact('sale','subCategory','bankAccount'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Sale $sale)
    {
        abort_if(Gate::denies('sale_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        // restrict if driveway sheet is approved on given date
        $driveway_sheet = DrivewaySheet::query()->where('branch_id',$this->branch_id)->whereDate('date',$sale->date);
        if ($driveway_sheet != null) {
            if($driveway_sheet->first()->is_approved)
            {
                toastr()->error('Sale can\'t be edit!');
                return redirect()->route('admin.driveway-sheets.index');
            }
        }

        $request->validate([
            'date' => 'required',
            // 'title' => 'required|string|max:40|unique:sales,id,'.$sale->id,
            'sub_category' => 'required|integer',
            'amount' => 'required|numeric',
            'detail' => 'nullable|string',
        ]);
        $detail = $request->detail? $request->detail : null;
        $req_date = strtr($request->date,'/','-');
        $date = date('Y-m-d',strtotime($req_date));
        $sale->update([
            'date' => $date,
            'sub_category_id' => $request->sub_category,
            'amount' => $request->amount,
            'detail' => $detail,
            'branch_id' => $this->branch_id,
        ]);
        toastr()->info('Sale has been updated successfully!');
        return redirect('admin/sales?date='.$date);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Sale $sale)
    {
        abort_if(Gate::denies('sale_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        // restrict if driveway sheet is approved on given date
        $driveway_sheet = DrivewaySheet::query()->where('branch_id',$this->branch_id)->whereDate('date',$sale->date);
        if ($driveway_sheet != null) {
            if($driveway_sheet->first()->is_approved)
            {
                toastr()->error('Sale can\'t be delete!');
               return redirect()->route('admin.driveway-sheets.index');
            }
        }

        $sale->forceDelete();
        toastr()->error('Sale has been deleted!');
        return redirect('admin/sales?date='.$sale->date);
    }

    public function massDestroy(Request $request)
    {
        abort_if(Gate::denies('sale_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');
        $request->validate([
            'ids'   => 'required|array',
            'ids.*' => 'exists:sales,id',
        ]);

        foreach($request->ids as $id){
            $sale = Sale::find($id);
            $this->destroy($sale);
        }
        // toastr()->error('Sale has been deleted!');
        return response(null, Response::HTTP_NO_CONTENT);
    }
}
