<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\MassDestroySheelCardRequest;
use App\Http\Requests\StoreSheelCardRequest;
use App\Http\Requests\UpdateSheelCardRequest;
use App\Imports\ShellCardImport;
use App\Models\Fuel;
use App\Models\FuelInfo;
use App\Models\SheelCard;
use App\Models\SitePump;
use App\Models\SiteRegister;
use App\Models\SubShellCard;
use Illuminate\Http\Request;
use Gate;
use Excel;
use Illuminate\Support\Facades\DB;
use Symfony\Component\HttpFoundation\Response;
use Yajra\DataTables\Facades\DataTables;

class SheelCardController extends Controller
{
    /**
     * Display a listing of the Sheel Card.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        abort_if(Gate::denies('sheel_card_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');
        $sheel_card = SheelCard::where('branch_id',session()->get('branch_id'))->select('*',DB::raw('sum(amount) as daytotal'))->groupBy('date')->get()->pluck('date','daytotal');
        return view('admin.sheelCards.index',compact('sheel_card'));
    }

    /**
     * Show the form for creating a new Shell Card.
     *
     * @return Symfony\Component\HttpFoundation\Response
     */
    public function create()
    {
        abort_if(Gate::denies('sheel_card_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');
        $site = SiteRegister::where('id',session()->get('branch_id'))->first();
        $fuel =  collect();
        if (!empty($site)) {
            $fuel = $site->fuels->unique()->pluck('fuel_name','id');
        }

        return view('admin.sheelCards.create',compact('fuel'));
    }

    /**
     * Store a newly created Shell Card in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return Symfony\Component\HttpFoundation\Response
     */
    public function store(StoreSheelCardRequest $request)
    {
        $site = SiteRegister::where('id',session()->get('branch_id'))->first();
        $fuel = collect();
        if (!empty($site)) {
            $fuel = $site->fuels->unique()->pluck('fuel_name','id');
        }
        foreach ($request->ticket_no as $key => $value) {

            // replace d/m/Y to Y-m-d
            $req_date = strtr($request->date,'/','-');
            $date = date('Y-m-d',strtotime($req_date));

            // for fuel_id, fuel_price, total_amount and quantity
            $fuel_price = [];
            $total_amount = null;

            //fuel prices
            $fuel_info = FuelInfo::where('branch_id',session()->get('branch_id'))->where('status',1)->first();
            foreach ($fuel as $f_id => $f_val) {
                // fuel value is not null
                if ($request->fuel[$key][$f_id] != null) {
                    $fuelprice = $fuel_info->where('fuel_id',$f_id)->first();
                    if (!empty($fuelprice)) {
                        $fuel_price[$f_id] = $fuelprice->selling_price;
                        $total_amount += (float)($request->fuel[$key][$f_id]) * $fuel_price[$f_id];
                    }
                }
            }

            $shell_card_store = SheelCard::create([
                'date' => $date,
                'type' => $request->type,
                'ticket_no' => $request->ticket_no[$key],
                'card_no' => $request->card_no[$key],
                'amount' => $total_amount,
                'branch_id' => session()->get('branch_id'),
                // 'shift_total' =>$request->shift_total[$key],
                // 'daily_total' =>$request->daily_total[$key],
            ]);

            // Entry for every fuel
            if(!empty($shell_card_store)){
                foreach ($fuel as $f_id => $f_val) {
                    if ($request->fuel[$key][$f_id] != null) {
                        SubShellCard::create([
                            'shell_card_id' => $shell_card_store->id,
                            'fuel_id' => $f_id,
                            'fuel_price' => $fuel_price[$f_id],
                            'quantity' => $request->fuel[$key][$f_id],
                        ]);
                    }
                }
            }
        }

        if ($request->ajax()) {
            return response()->json(['success'=>true,'message'=>'Shell card added successfully!','url'=> route('admin.sheel-cards.index')]);
        }
        toastr()->success('Shell card is created successfully!');
        return redirect()->route('admin.sheel-cards.index');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return Symfony\Component\HttpFoundation\Response
     */
    public function show($date)
    {
        abort_if(Gate::denies('sheel_card_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');
        $sheel_card = SheelCard::select('*')->with('sub_shell_card')->where('branch_id',session()->get('branch_id'))->where('date',$date)->groupBy('ticket_no')->get();
        $site = SiteRegister::where('id',session()->get('branch_id'))->first();
        $fuel = collect();
        if (!empty($site)) {
            $fuel = $site->fuels->unique()->pluck('fuel_name','id');
        }
        $total = $sheel_card->sum('amount');
        return view('admin.sheelCards.show', compact('sheel_card','date','fuel','total'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return Symfony\Component\HttpFoundation\Response
     */
    public function edit($date)
    {
        abort_if(Gate::denies('sheel_card_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $sheel_card = SheelCard::where('branch_id',session()->get('branch_id'))->where('date',$date)->get();
        $type = SheelCard::where('branch_id',session()->get('branch_id'))->where('date',$date)->get('type')->first();
        $site = SiteRegister::where('id',session()->get('branch_id'))->first();
        $fuel = collect();
        if (!empty($site)) {
            $fuel = $site->fuels->unique()->pluck('fuel_name','id');
        }
        return view('admin.sheelCards.edit', compact('sheel_card','date','fuel','type'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return Symfony\Component\HttpFoundation\Response
     */
    public function update(UpdateSheelCardRequest $request, $update_date)
    {
        // dd($request->input());
        $site = SiteRegister::where('id',session()->get('branch_id'))->first();
        $fuel = collect();
        if (!empty($site)) {
            $fuel = $site->fuels->unique()->pluck('fuel_name','id');
        }

        // For New created element during edit
        if ($request->has('ticket_no_new') && $request->has('card_no_new')) {
            foreach ($request->ticket_no_new as $key => $value) {

                // replace d/m/Y to Y-m-d
                $req_date = strtr($request->date,'/','-');
                $date = date('Y-m-d',strtotime($req_date));

                // for fuel_id, fuel_price, total_amount and quantity
                $fuel_price = [];
                $total_amount = null;

                $fuel_info = FuelInfo::where('branch_id',session()->get('branch_id'))->where('status',1)->first();
                foreach ($fuel as $f_id => $f_val) {
                    // fuel value is not null
                    if ($request->fuel_new[$key][$f_id] != null) {
                        $fuelprice = $fuel_info->where('fuel_id',$f_id)->first();
                        if (!empty($fuelprice)) {
                            $fuel_price[$f_id] = $fuelprice->selling_price;
                            $total_amount += (float)($request->fuel_new[$key][$f_id]) * $fuel_price[$f_id];
                        }
                    }
                }

                $shell_card_store = SheelCard::create([
                    'date' => $date,
                    'type' => $request->type,
                    'ticket_no' => $request->ticket_no_new[$key],
                    'card_no' => $request->card_no_new[$key],
                    'amount' => $total_amount,
                    'branch_id' => session()->get('branch_id'),
                ]);

                if(!empty($shell_card_store)){
                // Entry for every fuel
                    foreach ($fuel as $f_id => $f_val) {
                        if ($request->fuel_new[$key][$f_id] != null) {
                            SubShellCard::create([
                                'shell_card_id' => $shell_card_store->id,
                                'fuel_id' => $f_id,
                                'fuel_price' => $fuel_price[$f_id],
                                'quantity' => $request->fuel_new[$key][$f_id],
                            ]);
                        }
                    }
                }
            }
        }

        // Update for existing records
        foreach ($request->ticket_no as $key => $value) {
            // Find ID in Shell Card table
            $shell_card_update = SheelCard::find($key);
            $req_date = strtr($request->date,'/','-');
            $date = date('Y-m-d',strtotime($req_date));

            if (!empty($shell_card_update)) {
                $fuel_price = [];
                $total_amount = null;

                $fuel_info = FuelInfo::where('branch_id',session()->get('branch_id'))->where('status',1)->first();
                foreach ($fuel as $f_id => $f_val) {

                    // fuel value is not null
                    if ($request->fuel[$key][$f_id] != null) {
                        $fuelprice = $fuel_info->where('fuel_id',$f_id)->first();
                        if (!empty($fuelprice)) {
                            $fuel_price[$f_id] = $fuelprice->selling_price;
                            $total_amount += (float)($request->fuel[$key][$f_id]) * $fuel_price[$f_id];
                        }
                    }
                }

                $shell_card_update->update([
                    'date' => $date,
                    'type' => $request->type,
                    'ticket_no' => $request->ticket_no[$key],
                    'card_no' => $request->card_no[$key],
                    'amount' => $total_amount,
                    'branch_id' => session()->get('branch_id'),
                ]);

                // Update for every fuel
                foreach ($fuel as $f_id => $f_val) {
                    if ($request->fuel[$key][$f_id] != null) {
                        // Find shell card id for particular fuel
                        $sub_shell_card_update = SubShellCard::where('shell_card_id',$key)->where('fuel_id',$f_id)->first();
                        if (!empty($sub_shell_card_update)) {
                            $sub_shell_card_update->update([
                                'shell_card_id' => $key,
                                'fuel_id' => $f_id,
                                'fuel_price' => $fuel_price[$f_id],
                                'quantity' => $request->fuel[$key][$f_id],
                            ]);
                        }
                        else
                        {
                            // create whenever new fuel value is added
                            SubShellCard::create([
                                'shell_card_id' => $key,
                                'fuel_id' => $f_id,
                                'fuel_price' => $fuel_price[$f_id],
                                'quantity' => $request->fuel[$key][$f_id],
                            ]);
                        }
                    }
                    else
                    {
                        // For existing fuel quantity change into null
                        $sub_shell_card_delete = SubShellCard::where('shell_card_id',$key)->where('fuel_id',$f_id)->first();
                        if (!empty($sub_shell_card_delete)) {
                            $sub_shell_card_delete->forceDelete();
                        }
                    }
                }
            }
        }
        if ($request->ajax()) {
            return response()->json(['success'=>true,'message'=>'Shell has been updated successfully!','url'=> route('admin.sheel-cards.index')]);
        }
        // toastr()->info('Shell has been updated successfully!');
        // return redirect()->route('admin.sheel-cards.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return Symfony\Component\HttpFoundation\Response
     */
    public function destroy($date)
    {
        abort_if(Gate::denies('sheel_card_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $sheelCard = SheelCard::where('branch_id',session()->get('branch_id'))->where('date',$date)->get();
        foreach ($sheelCard as $del_card) {
            $del_card->forceDelete();
        }
        toastr()->error("Shell card has been deleted!");
        return back();
    }

    public function destroyParticular($id)
    {
        abort_if(Gate::denies('sheel_card_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $sheel_card_par = SheelCard::where('id',$id)->get();
        foreach ($sheel_card_par as $sc_par) {
            $sc_par->forceDelete();
        }
        toastr()->error("Shell card has been deleted from list!");
        return back();
    }

    public function destroyEdit(Request $request)
    {
        abort_if(Gate::denies('sheel_card_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $sheel_card = SheelCard::where('id',$request->id)->first();
        if (!empty($sheel_card)) {
            $sheel_card->forceDelete();
            return response()->json(['message' => 'Shel card has been deleted!']);
        }
    }

    /**
     * massDestroy for
     * destroy multiple
     * Sheel Card using ids
     *
     * @param  mixed $request
     * @return void
     */
    public function massDestroy(MassDestroySheelCardRequest $request)
    {
        SheelCard::whereIn('id', request('ids'))->forceDelete();

        return response(null, Response::HTTP_NO_CONTENT);
    }

    // Shell Card Import
    public function shellCardImport(Request $request)
    {
        // dd($request->file('upload_file')->extension());
        if($request->file('upload_file')->extension() == 'xlsx' || $request->file('upload_file')->extension() == 'csv' )
        {
            Excel::import(new ShellCardImport,$request->file('upload_file'));
            toastr()->success("File Imported Successfully!");
            return back();
        }
        toastr()->error('File type is not correct!');
        return back();
    }
}
