<?php

namespace App\Http\Controllers\Api\v1\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\StoreCreditExpenseRequest;
use App\Http\Requests\UpdateCreditExpenseRequest;
use App\Http\Resources\Admin\CreditExpenseResource;
use App\Models\CreditExpense;
use Gate;
use Symfony\Component\HttpFoundation\Response;

class CreditExpensesApiController extends Controller
{
    public function index()
    {
        abort_if(Gate::denies('credit_expense_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new CreditExpenseResource(CreditExpense::with(['suplier'])->get());
    }

    public function store(StoreCreditExpenseRequest $request)
    {
        $creditExpense = CreditExpense::create($request->all());

        return (new CreditExpenseResource($creditExpense))
            ->response()
            ->setStatusCode(Response::HTTP_CREATED);
    }

    public function show(CreditExpense $creditExpense)
    {
        abort_if(Gate::denies('credit_expense_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new CreditExpenseResource($creditExpense->load(['suplier']));
    }

    public function update(UpdateCreditExpenseRequest $request, CreditExpense $creditExpense)
    {
        $creditExpense->update($request->all());

        return (new CreditExpenseResource($creditExpense))
            ->response()
            ->setStatusCode(Response::HTTP_ACCEPTED);
    }

    public function destroy(CreditExpense $creditExpense)
    {
        abort_if(Gate::denies('credit_expense_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $creditExpense->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
