<?php

namespace App\Http\Controllers\Api\V1\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\StoreCreditPurchaseRequest;
use App\Http\Requests\UpdateCreditPurchaseRequest;
use App\Http\Resources\Admin\CreditPurchaseResource;
use App\Models\CreditPurchase;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class CreditPurchaseApiController extends Controller
{
    public function index()
    {
        abort_if(Gate::denies('credit_purchase_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new CreditPurchaseResource(CreditPurchase::with(['suplier'])->get());
    }

    public function store(StoreCreditPurchaseRequest $request)
    {
        $creditPurchase = CreditPurchase::create($request->all());

        return (new CreditPurchaseResource($creditPurchase))
            ->response()
            ->setStatusCode(Response::HTTP_CREATED);
    }

    public function show(CreditPurchase $creditPurchase)
    {
        abort_if(Gate::denies('credit_purchase_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new CreditPurchaseResource($creditPurchase->load(['suplier']));
    }

    public function update(UpdateCreditPurchaseRequest $request, CreditPurchase $creditPurchase)
    {
        $creditPurchase->update($request->all());

        return (new CreditPurchaseResource($creditPurchase))
            ->response()
            ->setStatusCode(Response::HTTP_ACCEPTED);
    }

    public function destroy(CreditPurchase $creditPurchase)
    {
        abort_if(Gate::denies('credit_purchase_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $creditPurchase->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
