<?php

namespace App\Http\Controllers\Api\V1\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\StoreDrivewaySheetRequest;
use App\Http\Requests\UpdateDrivewaySheetRequest;
use App\Http\Resources\Admin\DrivewaySheetResource;
use App\Models\DrivewaySheet;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class DrivewaySheetApiController extends Controller
{
    public function index()
    {
        abort_if(Gate::denies('driveway_sheet_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new DrivewaySheetResource(DrivewaySheet::with(['pumps'])->get());
    }

    public function store(StoreDrivewaySheetRequest $request)
    {
        $drivewaySheet = DrivewaySheet::create($request->all());
        $drivewaySheet->pumps()->sync($request->input('pumps', []));

        return (new DrivewaySheetResource($drivewaySheet))
            ->response()
            ->setStatusCode(Response::HTTP_CREATED);
    }

    public function show(DrivewaySheet $drivewaySheet)
    {
        abort_if(Gate::denies('driveway_sheet_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new DrivewaySheetResource($drivewaySheet->load(['pumps']));
    }

    public function update(UpdateDrivewaySheetRequest $request, DrivewaySheet $drivewaySheet)
    {
        $drivewaySheet->update($request->all());
        $drivewaySheet->pumps()->sync($request->input('pumps', []));

        return (new DrivewaySheetResource($drivewaySheet))
            ->response()
            ->setStatusCode(Response::HTTP_ACCEPTED);
    }

    public function destroy(DrivewaySheet $drivewaySheet)
    {
        abort_if(Gate::denies('driveway_sheet_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $drivewaySheet->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
