<?php

namespace App\Http\Controllers\Api\v1\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\StoreSheelCardRequest;
use App\Http\Requests\UpdateSheelCardRequest;
use App\Http\Resources\Admin\SheelCardResource;
use App\Models\SheelCard;
use Illuminate\Http\Request;
use Gate;
use Symfony\Component\HttpFoundation\Response;

class SheelCardApiController extends Controller
{
    /**
     * Get
     * for All
     *  Details
     *
     * @return void
     */
    public function index()
    {
        abort_if(Gate::denies('sheel_card_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new SheelCardResource(SheelCard::where('deleted_at','=',null)->get());
    }

    /**
     * store for store
     * a new details
     *
     * @param  mixed $request
     * @return void
     */
    public function store(StoreSheelCardRequest $request)
    {
        $sheelCard = SheelCard::create($request->all());

        return (new SheelCardResource($sheelCard))
            ->response()
            ->setStatusCode(Response::HTTP_CREATED);
    }

    /**
     * show
     * for particular
     * details
     *
     * @param  mixed $sheelCard
     * @return void
     */
    public function show(SheelCard $sheelCard)
    {
        abort_if(Gate::denies('sheel_card_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return new SheelCardResource($sheelCard);
    }

    /**
     * update
     * for update
     * particular details
     *
     * @param  mixed $request
     * @param  mixed $sheelCard
     * @return void
     */
    public function update(UpdateSheelCardRequest $request, SheelCard $sheelCard)
    {
        $sheelCard->update($request->all());

        return (new SheelCardResource($sheelCard))
            ->response()
            ->setStatusCode(Response::HTTP_ACCEPTED);
    }

    /**
     * destroy
     * for delete
     * particular details
     *
     * @param  mixed $sheelCard
     * @return void
     */
    public function destroy(SheelCard $sheelCard)
    {
        abort_if(Gate::denies('sheel_card_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $sheelCard->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
