<?php

namespace App\Http\Controllers\Auth;

use App\Http\Controllers\Controller;
use App\Http\Requests\UpdatePasswordRequest;
use App\Http\Requests\UpdateProfileRequest;
use App\Models\Country;
use App\Models\User;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class ChangePasswordController extends Controller
{
    public function edit()
    {
        abort_if(Gate::denies('profile_password_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');
        $user = auth()->user();
        $countries = Country::all();
        return view('auth.passwords.edit',compact('user','countries'));
    }

    public function update(UpdatePasswordRequest $request)
    {
        auth()->user()->update($request->validated());
        toastr()->info('Password has been updated successfully!');
        return redirect()->route('profile.password.edit');
    }

    public function updateProfile(UpdateProfileRequest $request)
    {
        $input = $request->except('_token');
        $user = auth()->user();
        if ($file = $request->file('profile_pic')) {
            if (isset($user) && $user->profile_pic != null) {
                $image_file = @file_get_contents('../public/images/users/' . $user->profile_pic);
                if ($image_file) {
                    unlink('../public/images/users/' . $user->profile_pic);
                }
            }
            $optimizePath = '../public/images/users/';
            if (!file_exists($optimizePath)) {
                mkdir($optimizePath, 666, true);
            }
            $name = time() . '_users_' . $file->getClientOriginalName();
            $file->move($optimizePath, $name);
            $input['profile_pic'] = $name;
        }

        $input['dob'] = date('Y-m-d',strtotime(strtr($request->dob,'/','-')));

        $user->update($input);
        toastr()->info('Profile has been updated successfully!');
        return redirect()->route('profile.password.edit');
    }

    public function destroy()
    {
        $user = auth()->user();

        // $user->update([
        //     'email' => time() . '_' . $user->email,
        // ]);

        $user->forceDelete();
        toastr()->error('User has been deleted successfully!');
        return redirect()->route('login');
    }
}
