<?php

namespace App\Models;

use App\Traits\Auditable;
use Carbon\Carbon;
use DateTimeInterface;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;

class DepositOrSale extends Model
{
    use HasFactory;
    use SoftDeletes;
    use Auditable;


    protected $dates =[
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    public const VOUCHER_TYPE_SELECT = [
        'SALES'  => 'SALE',
        'DEPOSIT' => 'DEPOSIT',
    ];

    public const MODE_TYPE_SELECT = [
        'CASH'  => 'BY CASH',
        'CHEQUE' => 'BY CHEQUE',
        'CREDIT' => 'ON CREDIT'
    ];

    protected $guarded = [];

    public function getDateAttribute($value)
    {
        return $value ? Carbon::parse($value)->format(config('panel.date_format')) : null;
    }

    /**
     * setDateAttribute
     * for set the date format in Year-month-day
     * for database
     *
     * @param  mixed $value
     * @return void
     */
    public function setDateAttribute($value)
    {
        $this->attributes['date'] = $value ? Carbon::createFromFormat(config('panel.date_format'), $value)->format('Y-m-d') : null;
    }

    protected function serializeDate(DateTimeInterface $date)
    {
        return $date->format('Y-m-d H:i:s');
    }

    public function header()
    {
        return $this->belongsTo(\App\Models\Header::class);
    }


}
