<?php

namespace App\Models;

use App\Traits\Auditable;
use Carbon\Carbon;
use DateTimeInterface;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Support\Facades\DB;

class FuelStock extends Model
{
    use SoftDeletes;
    use HasFactory;
    use Auditable;

    protected $dates = [
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    public const FUEL_TYPE_SELECT = [
        'U L P 95'  => 'U L P 95',
        'U L P 93'  => 'U L P 93',
        'DIESEL 50' => 'DIESEL 50',
    ];

    protected $guarded = [];

    public function getDateAttribute($value)
    {
        return $value ? Carbon::parse($value)->format(config('panel.date_format')) : null;
    }

    /**
     * setDateAttribute
     * for set the date format in Year-month-day
     * for database
     *
     * @param  mixed $value
     * @return void
     */
    public function setDateAttribute($value)
    {
        $this->attributes['date'] = $value ? Carbon::createFromFormat(config('panel.date_format'), $value)->format('Y-m-d') : null;
    }

    protected function serializeDate(DateTimeInterface $date)
    {
        return $date->format('Y-m-d H:i:s');
    }

    public function fuel()
    {
        return $this->belongsTo(\App\Models\Fuel::class,'fuel_type');
    }
}
