<?php

namespace App\Models;

use \DateTimeInterface;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;
use App\Models\DrivewaySheet;
use App\Models\SitePump;
use App\Traits\Auditable;

class Pump extends Model
{
    use SoftDeletes;
    use Auditable;
    use HasFactory;

    public $table = 'pumps';

    public static $searchable = [
        'pump',
    ];

    protected $dates = [
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    protected $fillable = [
        'pump',
        'detail',
        'created_at',
        'updated_at',
        'deleted_at',
        'is_fake',
    ];

    protected function serializeDate(DateTimeInterface $date)
    {
        return $date->format('Y-m-d H:i:s');
    }

    public function drivewaysheet()
    {
        return $this->hasMany(DrivewaySheet::class);
    }

    public function sites()
    {
        return $this->belongsToMany(\App\Models\SiteRegister::class,'pump_site_register')->withPivot('fuel_id')->using(SitePump::class)->withTimestamps();
    }
    public function fuels()
    {
        return $this->belongsToMany(\App\Models\Fuel::class,'pump_site_register')->withPivot('site_register_id')->using(SitePump::class)->withTimestamps();
    }
    public function fuel($id)
    {
        return $this->fuels()->where('site_register_id',$id)->first();
    }
}
