<?php

Route::redirect('/', '/login');
Route::get('/home', function () {
    if (session('status')) {
        return redirect()->route('admin.home')->with('status', session('status'));
    }

    return redirect()->route('admin.home');
});

Auth::routes();

Route::group(['prefix' => 'admin', 'as' => 'admin.', 'namespace' => 'Admin', 'middleware' => ['auth']], function () {
    Route::get('/', 'HomeController@index')->name('home');
    // Permissions
    Route::delete('permissions/destroy', 'PermissionsController@massDestroy')->name('permissions.massDestroy');
    Route::resource('permissions', 'PermissionsController');

    // Roles
    Route::delete('roles/destroy', 'RolesController@massDestroy')->name('roles.massDestroy');
    Route::resource('roles', 'RolesController');

    // // Testing Purpose
    // Route::get('data-test','DrivewaySheetController@test');

    // Site Registration

    Route::delete('types/destroy','TypeController@massDestroy')->name('types.massDestroy');
    Route::resource('types', 'TypeController');

    Route::delete('site-registers/destroy','SiteRegisterController@massDestroy')->name('site-registers.massDestroy');
    Route::get('site-registers/state/{id}','SiteRegisterController@states');
    Route::get('site-registers/city/{id}','SiteRegisterController@cities');
    Route::resource('site-registers', 'SiteRegisterController');


    // Users
    Route::delete('users/destroy', 'UsersController@massDestroy')->name('users.massDestroy');
    Route::resource('users', 'UsersController');

    // Audit Logs
    Route::resource('audit-logs', 'AuditLogsController', ['except' => ['create', 'store', 'edit', 'update', 'destroy']]);

    // User Alerts
    Route::delete('user-alerts/destroy', 'UserAlertsController@massDestroy')->name('user-alerts.massDestroy');
    Route::get('user-alerts/read', 'UserAlertsController@read');
    Route::resource('user-alerts', 'UserAlertsController', ['except' => ['edit', 'update']]);

    // Pumps
    Route::delete('pumps/destroy', 'PumpsController@massDestroy')->name('pumps.massDestroy');
    // Route::post('pumps/parse-csv-import', 'PumpsController@parseCsvImport')->name('pumps.parseCsvImport');
    // Route::post('pumps/process-csv-import', 'PumpsController@processCsvImport')->name('pumps.processCsvImport');
    Route::post('pumps/import', 'PumpsController@pumpImport')->name('pumps.import');
    Route::resource('pumps', 'PumpsController');

    // Cash Expenses
    Route::delete('cash-expenses/destroy', 'CashExpensesController@massDestroy')->name('cash-expenses.massDestroy');
    Route::post('cash-expenses/parse-csv-import', 'CashExpensesController@parseCsvImport')->name('cash-expenses.parseCsvImport');
    Route::post('cash-expenses/process-csv-import', 'CashExpensesController@processCsvImport')->name('cash-expenses.processCsvImport');
    Route::resource('cash-expenses', 'CashExpensesController');

    // Credit Expenses
    Route::delete('credit-expenses/destroy', 'CreditExpensesController@massDestroy')->name('credit-expenses.massDestroy');
    Route::post('credit-expenses/parse-csv-import', 'CreditExpensesController@parseCsvImport')->name('credit-expenses.parseCsvImport');
    Route::post('credit-expenses/process-csv-import', 'CreditExpensesController@processCsvImport')->name('credit-expenses.processCsvImport');
    Route::resource('credit-expenses', 'CreditExpensesController');

     // Deposti Or Sales
     Route::delete('deposits-sales/destroy', 'DepositOrSaleController@massDestroy')->name('deposits-sales.massDestroy');
     Route::post('deposits-sales/parse-csv-import', 'DepositOrSaleController@parseCsvImport')->name('deposits-sales.parseCsvImport');
     Route::post('deposits-sales/process-csv-import', 'DepositOrSaleController@processCsvImport')->name('deposits-sales.processCsvImport');
     Route::resource('deposits-sales', 'DepositOrSaleController');

    // Suplier
    Route::delete('supliers/destroy', 'SuplierController@massDestroy')->name('supliers.massDestroy');
    Route::post('supliers/parse-csv-import', 'SuplierController@parseCsvImport')->name('supliers.parseCsvImport');
    Route::post('supliers/process-csv-import', 'SuplierController@processCsvImport')->name('supliers.processCsvImport');
    Route::resource('supliers', 'SuplierController');

    // Credit Purchase
    Route::delete('credit-purchases/destroy', 'CreditPurchaseController@massDestroy')->name('credit-purchases.massDestroy');
    Route::resource('credit-purchases', 'CreditPurchaseController');

    // Cash Purchase
    Route::delete('cash-purchases/destroy', 'CashPurchaseController@massDestroy')->name('cash-purchases.massDestroy');
    Route::resource('cash-purchases', 'CashPurchaseController');

    // Driveway Sheet
    Route::delete('driveway-sheets/destroy', 'DrivewaySheetController@massDestroy')->name('driveway-sheets.massDestroy');
    Route::post('driveway-sheets/parse-csv-import', 'DrivewaySheetController@parseCsvImport')->name('driveway-sheets.parseCsvImport');
    Route::post('driveway-sheets/process-csv-import', 'DrivewaySheetController@processCsvImport')->name('driveway-sheets.processCsvImport');
    Route::resource('driveway-sheets', 'DrivewaySheetController');

    // Fuel Stock
    Route::delete('fuel-stocks/destroy', 'FuelStockController@massDestroy')->name('fuel-stocks.massDestroy');
    Route::post('fuel-stocks/parse-csv-import', 'FuelStockController@parseCsvImport')->name('fuel-stocks.parseCsvImport');
    Route::post('fuel-stocks/process-csv-import', 'FuelStockController@processCsvImport')->name('fuel-stocks.processCsvImport');
    Route::resource('fuel-stocks', 'FuelStockController');

    // Headers for Deposit and Sales
    Route::delete('headers/destroy', 'HeaderController@massDestroy')->name('headers.massDestroy');
    Route::post('headers/parse-csv-import', 'HeaderController@parseCsvImport')->name('headers.parseCsvImport');
    Route::post('headers/process-csv-import', 'HeaderController@processCsvImport')->name('headers.processCsvImport');
    Route::resource('headers', 'HeaderController');

    // Fuel
    Route::delete('fuels/destroy', 'FuelController@massDestroy')->name('fuels.massDestroy');
    Route::post('fuels/parse-csv-import', 'FuelController@parseCsvImport')->name('fuels.parseCsvImport');
    Route::post('fuels/process-csv-import', 'FuelController@processCsvImport')->name('fuels.processCsvImport');
    Route::resource('fuels', 'FuelController');

    // Speed Point
    Route::delete('speed-points/destroy', 'SpeedPointController@massDestroy')->name('speed-points.massDestroy');
    Route::post('speed-points/parse-csv-import', 'SpeedPointController@parseCsvImport')->name('speed-points.parseCsvImport');
    Route::post('speed-points/process-csv-import', 'SpeedPointController@processCsvImport')->name('speed-points.processCsvImport');
    Route::resource('speed-points', 'SpeedPointController');

    // Sheel Card
    Route::delete('sheel-cards/destroy', 'SheelCardController@massDestroy')->name('sheel-cards.massDestroy');
    Route::post('sheel-cards/parse-csv-import', 'SheelCardController@parseCsvImport')->name('sheel-cards.parseCsvImport');
    Route::post('sheel-cards/process-csv-import', 'SheelCardController@processCsvImport')->name('sheel-cards.processCsvImport');
    Route::resource('sheel-cards', 'SheelCardController');

    // Payment Advice
    Route::delete('payment-advices/destroy', 'PaymentAdviceController@massDestroy')->name('payment-advices.massDestroy');
    Route::resource('payment-advices', 'PaymentAdviceController');

    // Account
    Route::delete('accounts/destroy', 'AccountController@massDestroy')->name('accounts.massDestroy');
    Route::post('accounts/parse-csv-import', 'AccountController@parseCsvImport')->name('accounts.parseCsvImport');
    Route::post('accounts/process-csv-import', 'AccountController@processCsvImport')->name('accounts.processCsvImport');
    Route::resource('accounts', 'AccountController');

    //Driveway Reports
    Route::get('driveway-reports','ReportController@driveway')->name('reports.driveway');
    Route::get('driveway-reports-view/{created_at}','ReportController@drivewayReport')->name('reports.drivewayReport');

    // Location
    Route::resource('country', 'CountryController');
    Route::post('country/bulk_delete', 'CountryController@bulk_delete')->name('country.bulk_delete');

    // Route::get('states', 'LocationController@states');
    // Route::get('city', 'LocationController@cities');

    //Cash Expense Report
    Route::get('cash-expense-report','ReportController@cashExpense')->name('reports.cashExpense');
    Route::get('cash-expense-export','ReportController@excelExportCashExpense')->name('export.reports.cashExpense');

    // Credit Expense Report
    Route::get('credit-expense-report','ReportController@creditExpense')->name('reports.creditExpense');
    Route::post('credit-expense-report','ReportController@postCreditExpense')->name('post.reports.creditExpense');
    Route::get('credit-expense-export','ReportController@excelExportCreditExpense')->name('export.reports.creditExpense');

    //Credit Purchase Report
    Route::get('credit-purchase-report','ReportController@creditPurchase')->name('reports.creditPurchase');
    Route::get('credit-purchase-export','ReportController@excelCreditPurchase')->name('export.reports.creditPurchase');

    //Cash Purchase Report
    Route::get('cash-purchase-report','ReportController@cashPurchase')->name('reports.cashPurchase');
    Route::get('cash-purchase-export','ReportController@excelCashPurchase')->name('export.reports.cashPurchase');

    //Payment Advice Report
    Route::get('payment-advice-report','ReportController@paymentAdvice')->name('reports.paymentAdvice');

    // WET Stock
    Route::get('wet-stock-report','ReportController@wetStock')->name('reports.wetStock');
    // Route::post('wet-stock-report','ReportController@postWetStock')->name('post.reports.wetStock');
    Route::get('wet-stock-report{fuel}','ReportController@wetStockFuelType')->name('reports.wetStockFuel');
    Route::get('test-export','ReportController@exportwetStock')->name('reports.export');

    // Direct Shop
    Route::get('direct-shop-report','ReportController@directShop')->name('reports.directShop');
    // Route::post('direct-shop-report','ReportController@postDirectShop')->name('post.reports.directShop');

    // Banking Shop
    Route::get('banking-shop-report','ReportController@bankingShop')->name('reports.bankingShop');
    // Route::post('banking-shop-report','ReportController@postBankingShop')->name('reports.bankingShop');

    // Banking FS
    Route::get('banking-fs-report','ReportController@bankingFS')->name('reports.bankingFs');
    // Route::post('banking-fs-report','ReportController@postBankingFS')->name('post.reports.bankingFs');

    // Daily Report
    Route::get('daily-report','ReportController@dailyReport')->name('reports.dailyReport');
    // Route::post('daily-report','ReportController@postDailyReport')->name('post.reports.dailyReport');

    Route::get('global-search', 'GlobalSearchController@search')->name('globalSearch');
    Route::get('messenger', 'MessengerController@index')->name('messenger.index');
    Route::get('messenger/create', 'MessengerController@createTopic')->name('messenger.createTopic');
    Route::post('messenger', 'MessengerController@storeTopic')->name('messenger.storeTopic');
    Route::get('messenger/inbox', 'MessengerController@showInbox')->name('messenger.showInbox');
    Route::get('messenger/outbox', 'MessengerController@showOutbox')->name('messenger.showOutbox');
    Route::get('messenger/{topic}', 'MessengerController@showMessages')->name('messenger.showMessages');
    Route::delete('messenger/{topic}', 'MessengerController@destroyTopic')->name('messenger.destroyTopic');
    Route::post('messenger/{topic}/reply', 'MessengerController@replyToTopic')->name('messenger.reply');
    Route::get('messenger/{topic}/reply', 'MessengerController@showReply')->name('messenger.showReply');

    // General Setting

    Route::get('general-setting','SettingController@generalSetting')->name('general.setting');
    Route::post('admin/setting/store', 'SettingController@store')->name('setting.store');
    Route::post('admin/setting/general_update+', 'SettingController@general_update')->name('setting.general_update');

    // SEO Setting

    Route::get('seo-setting','SettingController@seoSetting')->name('seo.setting');
    Route::post('admin/setting/seo_update', 'SettingController@seo_update')->name('seo.update');

    Route::get('mail-setting','ConfigController@mail')->name('mail.setting');
    Route::post('admin/setting/mail_update', 'ConfigController@mail_update')->name('mail.update');

    // PWA Setting
    Route::get('pwa-setting','SettingController@pwaSetting')->name('pwa.setting');
    Route::post('admin/pwa/update/setting', 'SettingController@updatesetting')->name('pwa.setting.update');
    Route::post('admin/pwa/update/icons/setting', 'SettingController@updateicons')->name('pwa.icons.update');

    // Social Login Setting
    Route::get('social-login','ConfigController@sociallogin')->name('social.login');
    Route::post('admin/setting/sociallogin_update', 'ConfigController@sociallogin_update')->name('sociallogin.update');
    Route::resource('social', 'SocialController');

    // Route::get('social-icon','SettingController@socialIcon')->name('social.icon');
    Route::get('backup-restore','SettingController@backupRestore')->name('backup.restore');
    Route::post('setting','SettingController@store')->name('setting.store');

});
Route::group(['prefix' => 'profile', 'as' => 'profile.', 'namespace' => 'Auth', 'middleware' => ['auth']], function () {
    // Change password
    if (file_exists(app_path('Http/Controllers/Auth/ChangePasswordController.php'))) {
        Route::get('password', 'ChangePasswordController@edit')->name('password.edit');
        Route::post('password', 'ChangePasswordController@update')->name('password.update');
        Route::post('profile', 'ChangePasswordController@updateProfile')->name('password.updateProfile');
        Route::post('profile/destroy', 'ChangePasswordController@destroy')->name('password.destroyProfile');
    }
});
