@extends('layouts.admin')
@section('content')
<div class="page-wrapper">
    <div class="content container-fluid">
        <div class="page-header">
            <div class="row align-items-center">
                <div class="col">
                    <h3 class="page-title">{{trans('cruds.account.title_singular')}}</h3>
                    <ul class="breadcrumb">
                        @if (isset($account_info))
                        <li class="breadcrumb-item"><a href="{{route('admin.home')}}">{{trans('global.dashboard') }}</a>
                        </li>
                        <li class="breadcrumb-item"><a
                                href="{{route('admin.account-infos.index')}}">{{trans('cruds.account.title')}}</a></li>
                        <li class="breadcrumb-item active">{{trans('global.edit')}}</li>
                        @else
                        <li class="breadcrumb-item"><a href="{{route('admin.home')}}">{{trans('global.dashboard') }}</a>
                        </li>
                        <li class="breadcrumb-item active">{{trans('cruds.account.title')}}</li>
                        @endif
                    </ul>
                </div>
                @if(isset($account_info))
                <div class="col-auto float-right ml-auto">
                    <a href="{{ route('admin.account-infos.index') }}" class="btn add-btn"> <i
                            class="la la-arrow-left"></i>{{ trans('global.back') }}</a>
                </div>
                @else
                {{-- <div class="col-auto float-right ml-auto">
                        <a href="" class="btn add-btn"> <i class="fa fa-plus"></i>{{ trans('global.add')}}
                {{trans('cruds.account.title_singular')}}</a>
            </div> --}}
            @endif
        </div>
    </div>
    @can(['driveway_account_info_create','driveway_account_info_edit'])
        <div class="card">
            <div class="card-header">
                @if (isset($account_info))
                {{ trans('global.edit') }} {{ trans('cruds.account.title_singular') }}
                @else
                {{ trans('global.add') }} {{ trans('cruds.account.title_singular') }}
                @endif
                {{-- <span style="float: right;">
                            <a href="#" class="text-danger"><i class="fa fa-close"></i></a>
                        </span> --}}
            </div>
            <div class="card-body">
                @if (isset($account_info))
                <form action="{{route('admin.account-infos.update',[$account_info->id])}}" method="POST" enctype="multipart/form-data">
                    @method('PUT')
                    @else
                    <form action="{{route('admin.account-infos.store')}}" method="post" enctype="multipart/form-data">
                        @endif
                        <div class="row">
                            @csrf
                            <div class="col-lg-4">
                                <div class="form-group">
                                    <label class="required" for="title">{{ trans('cruds.account.fields.account_name') }}</label>
                                    <input class="form-control {{ $errors->has('title') ? 'is-invalid' : '' }}" type="text"
                                        name="title" id="title"
                                        value="{{ old('title', isset($account_info)?$account_info->title: '') }}" required>
                                    @if($errors->has('title'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('title') }}
                                    </div>
                                    @endif
                                    <span class="help-block">{{ trans('cruds.account.fields.account_name_helper') }}</span>
                                </div>
                            </div>
                            <div class="col-lg-4">
                                <div class="form-group">
                                    <label for="remarks">{{ trans('cruds.account.fields.remarks') }}</label>
                                    <input class="form-control {{ $errors->has('remarks') ? 'is-invalid' : '' }}"
                                        type="text" name="remarks" id="remarks"
                                        value="{{ old('remarks', isset($account_info)?$account_info->remarks:'') }}">
                                    @if($errors->has('remarks'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('remarks') }}
                                    </div>
                                    @endif
                                    <span class="help-block">{{ trans('cruds.account.fields.remarks_helper') }}</span>
                                </div>
                            </div>
                            <div class="col-lg-4 custom-switch">
                                <div class="form-group">
                                    <br>
                                    <label class="custom-switch">
                                        <input id="status" type="checkbox"
                                            {{isset($account_info)?($account_info->status? 'checked':''):''}} value="1" name="status"
                                            class="custom-control-input">
                                        <label class="custom-control-label" for="status">
                                            {{ trans('cruds.account.fields.status') }}</label>
                                    </label>
                                </div>
                            </div>
                        </div>
                        <div class="row">
                            <div class="col-lg-12">
                                @if (isset($account_info))
                                <button class="btn btn-primary" type="submit">{{ trans('global.update') }}</button>
                                @else
                                <button class="btn btn-info" type="reset">{{ trans('global.reset') }}</button>
                                <button class="btn btn-primary" type="submit">{{ trans('global.add') }}</button>
                                @endif
                            </div>
                        </div>
                    </form>
            </div>
        </div>
    @endcan

    <div class="card">
        <div class="card-header">
            {{ trans('global.list') }} {{ trans('cruds.account.title_singular') }}
        </div>
        <div class="card-body">
            <table class="table table-bordered datatable-account-info">
                <thead>
                    <tr>
                        <th style="width: 10px;"></th>
                        <th>
                            {{__('ID')}}
                        </th>
                        <th>
                            {{ trans('cruds.account.fields.account_name') }}
                        </th>
                        <th>
                            {{ trans('cruds.account.fields.remarks') }}
                        </th>
                        <th>
                            {{ trans('cruds.account.fields.status') }}
                        </th>
                        <th></th>
                    </tr>
                </thead>
                <tbody>
                    @if (count($account_info_list) == 0)
                        <tr>
                            <td colspan="3" style="text-align: center;">
                                <span>Records not found</span>
                            </td>
                        </tr>
                    @else
                        @php
                            $i = 1;
                        @endphp
                        @foreach ($account_info_list as $ml)
                            <tr data-entry-id="{{$ml->id}}">
                                <td></td>
                                <td>
                                    {{$i}}
                                </td>
                                <td>
                                    {{ucfirst($ml->title)}}
                                </td>
                                <td>
                                    {{$ml->remarks}}
                                </td>
                                <td>
                                    {!!$ml->status? '<span class="badge bg-inverse-success">Active</span>' : '<span class="badge bg-inverse-danger">Inactive</span>'!!}
                                </td>
                                <td>
                                    <div class="button-list">
                                        @can('driveway_account_info_edit')
                                            <a href="{{route('admin.account-infos.edit', $ml->id)}}" class="btn btn-xs btn-info"><i
                                                    class="la la-edit"></i></a>
                                        @endcan
                                        @can('driveway_account_info_delete')
                                            <button type="button" class="btn btn-xs btn-danger" data-toggle="modal"
                                                data-target="#deleteModal{{$ml->id}}"><i class="la la-trash"></i></button>
                                        @endcan
                                        <!-- Modal -->
                                        <div id="deleteModal{{$ml->id}}" class="delete-modal modal fade" role="dialog">
                                            <div class="modal-dialog modal-sm">
                                                <div class="modal-content">
                                                    <div class="modal-header">
                                                        <button type="button" class="close" data-dismiss="modal">&times;</button>
                                                        <div class="delete-icon"></div>
                                                    </div>
                                                    <div class="modal-body text-center">
                                                        <h4 class="modal-heading">Are You Sure ?</h4>
                                                        <p>Do you really want to delete these records?<br> This process cannot be
                                                            undone.</p>
                                                    </div>
                                                    <div class="modal-footer">
                                                        {!! Form::open(['method' => 'DELETE', 'route' => ['admin.account-infos.destroy',$ml->id]]) !!}
                                                        <button type="reset" class="btn btn-dark" data-dismiss="modal">No</button>
                                                        <button type="submit" class="btn btn-danger">Yes</button>
                                                        {!! Form::close() !!}
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </td>
                                @php
                                    $i++;
                                @endphp
                            </tr>
                        @endforeach
                    @endif
                </tbody>
            </table>
        </div>
    </div>
</div>
@endsection
@section('scripts')
    <script>
        $(function () {
            let dtButtons = $.extend(true, [], $.fn.dataTable.defaults.buttons)
            @can('driveway_account_info_delete')
            let deleteButtonTrans = '{{ trans('global.datatables.delete') }}'
            let deleteButton = {
                text: deleteButtonTrans,
                url: "{{ route('admin.account-infos.massDestroy') }}",
                className: 'bg-inverse-danger',
                action: function (e, dt, node, config) {
                var ids = $.map(dt.rows({ selected: true }).nodes(), function (entry) {
                    return $(entry).data('entry-id')
                });

                if (ids.length === 0) {
                    alert('{{ trans('global.datatables.zero_selected') }}')

                    return
                }

                if (confirm('{{ trans('global.areYouSure') }}')) {
                    $.ajax({
                    headers: {'x-csrf-token': _token},
                    method: 'POST',
                    url: config.url,
                    data: { ids: ids, _method: 'DELETE' }})
                    .done(function () { location.reload() })
                }
                }
            }
            dtButtons.push(deleteButton)
            @endcan

            $.extend(true, $.fn.dataTable.defaults, {
                orderCellsTop: true,
                order: [[ 1, 'desc' ]],
                pageLength: 100,
            });
            let table = $('.datatable-account-info').DataTable({ buttons: dtButtons })
            $('a[data-toggle="tab"]').on('shown.bs.tab click', function(e){
                $($.fn.dataTable.tables(true)).DataTable()
                    .columns.adjust();
            });
            $('div#sidebar').on('transitionend', function(e) {
                $($.fn.dataTable.tables(true)).DataTable().columns.adjust();
            })

        })
    </script>
@endsection
