@extends('layouts.admin')
@section('content')
<div class="page-wrapper">
    <div class="content container-fluid">
        <div class="page-header">
            <div class="row align-items-center">
                <div class="col">
                    <h3 class="page-title">{{trans('cruds.cashPurchase.title_singular')}}</h3>
                    <ul class="breadcrumb">
                        <li class="breadcrumb-item"><a href="{{route('admin.home')}}">{{trans('global.dashboard') }}</a></li>
                        <li class="breadcrumb-item"><a href="{{route('admin.cash-purchases.index')}}">{{trans('cruds.cashPurchase.title') }}</a></li>
                        <li class="breadcrumb-item active">{{trans('global.add')}}</li>
                    </ul>
                </div>
                <div class="col-auto float-right ml-auto">
                    <a href="{{ route('admin.cash-purchases.index') }}" class="btn add-btn"> <i class="la la-arrow-left"></i>{{ trans('global.back') }}</a>
                </div>
            </div>
        </div>
        <div class="card">
            <div class="card-header">
                {{ trans('global.add') }} {{ trans('cruds.cashPurchase.title') }}
            </div>

            <div class="card-body">
                <form method="POST" id="purchase_form" action="{{ route("admin.cash-purchases.store") }}" enctype="multipart/form-data">
                    @csrf
                    <div class="row">
                        <div class="col-lg-4">
                            <div class="form-group">
                                <label for="bank_account">{{trans('cruds.cashPurchase.fields.bank_account')}}</label>
                                <select name="bank_account" class="form-control" id="bank_account">
                                    @foreach ($bankAccounts as $key => $value )
                                        <option value="{{$key}}">{{$value}}</option>
                                    @endforeach
                                </select>
                            </div>
                        </div>
                        <div class="col-lg-4">
                            <div class="form-group">
                               <label for="date">{{ trans('cruds.cashPurchase.fields.date') }}</label>
                               <input type="text" name="date" id="date" class="form-control date {{$errors->has('date')? 'is-invalid':''}}" required>
                               @if ($errors->first('date'))
                                   <div class="invalid-feedback">
                                       {{$errors->first('date')}}
                                   </div>
                               @endif
                           </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-lg-12">
                            <table class="table table-bordered" id="field_container">
                                <tr>
                                    <th>{{trans('cruds.cashPurchase.fields.invoice_no')}} </th>
                                    <th>{{trans('cruds.cashPurchase.fields.suplier')}} </th>
                                    <th>{{trans('cruds.cashPurchase.fields.financial_category')}} </th>
                                    <th>{{trans('cruds.cashPurchase.fields.cash_credit')}} </th>
                                    <th>{{trans('cruds.cashPurchase.fields.reference')}} </th>
                                    <th>{{trans('cruds.cashPurchase.fields.vat')}} </th>
                                    <th>{{trans('cruds.cashPurchase.fields.total_amount')}} </th>
                                    <th></th>
                                </tr>
                                <tr id="copy_content" class="fuel_block">
                                    <td>
                                        <span>
                                            <div class="form-group small">
                                                <input type="file" name="attachment[0]" id="attach">
                                            </div>
                                        </span>
                                        <div class="form-group small">
                                            <input type="text" class="form-control {{ $errors->has('invoice_no.*') ? 'is-invalid' : ''}}" id="invoice_no" name="invoice_no[0]" value="{{ old('invoice_no[0]') }}">
                                            @if($errors->first('invoice_no.*'))
                                                <div class="invalid-feedback">
                                                    {{ $errors->first('invoice_no.*') }}
                                                </div>
                                            @endif
                                            <span class="help-block">{{ trans('cruds.cashPurchase.fields.invoice_no_helper') }}</span>
                                        </div>
                                    </td>
                                    <td>
                                        <div class="form-group small">
                                            <select name="suplier[0]" class="form-control" id="suplier">
                                                @foreach ($supliers as $key => $value )
                                                    <option value="{{$key}}">{{$value}}</option>
                                                @endforeach
                                            </select>
                                        </div>
                                    </td>
                                    <td>
                                        <div class="form-group small">
                                            <select name="financial_category[0]" class="form-control" id="financial_category">
                                                @foreach ($headers as $key => $value )
                                                    <option value="{{$key}}">{{$value}}</option>
                                                @endforeach
                                            </select>
                                        </div>
                                    </td>
                                    <td>
                                        <div class="form-group small">
                                            <select name="cash_credit[0]" class="form-control" id="cash_credit">
                                            <option value="Cash" selected>{{__('Cash')}}</option>
                                            <option value="Credit">{{__('Credit')}}</option>
                                            </select>
                                        </div>
                                    </td>
                                    <td>
                                        <div class="form-group small">
                                            <input type="text" class="form-control {{ $errors->has('reference') ? 'is-invalid' : ''}}" id="reference" name="reference[0]" value="{{ old('reference[0]') }}">
                                            @if($errors->first('reference.*'))
                                                <div class="invalid-feedback">
                                                    {{ $errors->first('reference.*') }}
                                                </div>
                                            @endif
                                            <span class="help-block">{{ trans('cruds.cashPurchase.fields.date_helper') }}</span>
                                        </div>
                                    </td>
                                    <td>
                                        {{-- <span>
                                            <div class="form-group small">
                                                <input type="checkbox" name="isvat[0]" id="vat_check">
                                            </div>
                                        </span> --}}
                                        <span>
                                            <div class="form-group small">
                                                <select name="vat[0]" class="form-control" id="vat">
                                                    @foreach ($vat as $key => $value)
                                                        <option value="{{$key}}">{{$value}}</option>
                                                    @endforeach
                                                </select>
                                            </div>
                                        </span>
                                    </td>
                                    <td>
                                        <div class="form-group small">
                                            <input type="number" min="1" step="any" class="form-control {{ $errors->has('total_amount') ? 'is-invalid' : ''}}" id="total_amount" name="total_amount[0]" value="{{ old('total_amount[0]') }}">
                                            @if($errors->first('total_amount.*'))
                                                <div class="invalid-feedback">
                                                    {{ $errors->first('total_amount.*') }}
                                                </div>
                                            @endif
                                            <span class="help-block">{{ trans('cruds.cashPurchase.fields.date_helper') }}</span>
                                        </div>
                                    </td>
                                    <td><a href="#" class="btn btn-xs btn-danger d-none" id="remove"><i class="fa fa-trash"></i></a></td>
                                </tr>
                            </table>
                        </div>
                    </div>
                    <div class="row my-3">
                        <div class="col-lg-12 text-center">
                            <button class="btn btn-block btn-light" id="add_row">Add Row</button>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-lg-12">
                            <div class="form-group">
                                <button class="btn btn-info" type="reset">
                                    {{ trans('global.reset') }}
                                </button>
                                <button class="btn btn-primary" id="btn_submit" type="submit">
                                    {{ trans('global.save') }}
                                </button>
                            </div>
                        </div>
                    </div>
                </form>
            </div>
        </div>
    </div>
</div>

@section('scripts')
    <script>
        $(document).ready(function(){
            var max = 15;
           var x=0;

            $('#add_row').click(function (e) {
                e.preventDefault();
                if(x < max)
                {
                    x++;
                    var clone_ele = $('#copy_content').clone();
                    clone_ele.find('#remove').removeClass('d-none');
                    clone_ele.find(':input').each(function(){
                        this.value = '';
                        this.id = this.id + '-' + x;
                        this.name = this.name.replace(/\[[0-9]\]+/, '[' + x + ']');
                    });
                    clone_ele.appendTo('#field_container');
                }
            });


            $('#field_container').on('click','#remove',function (e) {
                e.preventDefault();
                $(this).closest('tr').remove();
            });
            var i = 0;            
            $('#purchase_form').on("submit",function (e) {
                e.preventDefault();
                $("#btn_submit").prop('disabled', true);
               $.ajax({
                   type: this.method,
                   url: this.action,
                   data:new FormData(this),
                   dataType:'JSON',
                   contentType: false,
                   cache: false,
                   processData: false,
                   beforeSend: function(response){
                   },
                   success: function (response) {
                    if (response.success) {
                        toastr.success(response.message);
                        document.getElementById('purchase_form').reset();
                        setTimeout(function(){
                            window.location = response.url;
                        },1000);
                    }
                    $("#btn_submit").prop('disabled', false);
                   },
                   error: function(response){
                    $.each(response.responseJSON.errors, function (index, value) {
                        toastr.error(value);
                        $("#btn_submit").prop('disabled', false);
                    });
                   }
               });
            });
        });
    </script>
@endsection
@endsection
