@extends('layouts.admin')
@section('content')
<div class="page-wrapper">
    <div class="content container-fluid">
        {{-- page Header --}}
        <div class="page-header">
            <div class="row align-items-center">
                <div class="col">
                    <h3 class="page-title">{{trans('cruds.drivewaySheet.title_singular')}}</h3>
                    <ul class="breadcrumb">
                        <li class="breadcrumb-item"><a href="{{route('admin.home')}}">{{trans('global.dashboard') }}</a></li>
                        <li class="breadcrumb-item"><a href="{{route('admin.driveway-sheets.index')}}">{{trans('cruds.drivewaySheet.title_singular') }}</a></li>
                        <li class="breadcrumb-item active">{{trans('global.edit')}}</li>
                    </ul>
                </div>
                @can('pump_create')
                    <div class="col-auto float-right ml-auto">
                        <a href="{{ route('admin.driveway-sheets.index') }}" class="btn add-btn"> <i class="la la-arrow-left"></i> {{ trans('global.back') }}</a>
                    </div>
                @endcan
            </div>
        </div>
        {{-- end Page header --}}
        <div class="card">
            @include('partials.drivewayPartial')  
            <div class="card-header">
                {{ trans('global.edit') }} {{ trans('cruds.drivewaySheet.title_singular') }}
            </div>
            <div class="card-body">
                @php
                    $fuellist = isset($fuelstock) && count($fuelstock) > 0 ? $fuelstock : $fuels;
                @endphp
                <form method="POST"  class="driveway-form" action="{{ route('admin.driveway-sheets.save') }}" enctype="multipart/form-data">
                @csrf
                    <div class="row">
                        <div class="col-lg-4">
                            <div class="form-group">
                                <label class="required" for="date">{{ trans('cruds.drivewaySheet.fields.date') }}</label>
                                <input class="form-control date {{ $errors->has('date') ? 'is-invalid' : '' }}" type="text" name="date"
                                    id="date" value="{{ old('date', date('d/m/Y',strtotime($date))) }}" required readonly>
                                @if($errors->has('date'))
                                <div class="invalid-feedback">
                                    {{ $errors->first('date') }}
                                </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.drivewaySheet.fields.date_helper') }}</span>
                            </div>
                        </div>
                    </div>
                    <table id="custom_table" class="table table-bordered">
                        <thead>
                            <th>{{ trans('cruds.pump.fields.pump') }}</th>
                            <th>{{ trans('cruds.drivewaySheet.fields.opening') }}</th>
                            <th>{{ trans('cruds.drivewaySheet.fields.closing') }}</th>
                            @foreach($fuels as $key => $fuel)
                                <th>{{ $fuel }}</th>
                            @endforeach
                          <!--   @if($auth->is_admin == 1)
                            <th>{{ trans('global.action') }}</th>
                            @endif -->
                        </thead>
                        <tbody>
                            @foreach($drivesheet as $key => $data)
                                <tr class="driveway-stock">
                                    <td>
                                        <input type="hidden" name="id[{{$key}}]" value="{{$data->id}}" readonly>
                                        <input type="hidden" name="fuel_id[{{$key}}]" value="{{$data->fuel_id}}" readonly>
                                        <input type="hidden" class="stock-value" name="stock[{{$key}}]" value="{{ old('stock[$key]',$data->stock) }}" readonly>
                                        <input type="hidden" name="pump_id[{{$key}}]" value="{{$data->pump_id}}" readonly>
                                        <div class="form-group small">
                                            <input type="text" class="form-control {{ $errors->has('pump_name') ? 'is-invalid' : ''}}" name="pump_name[{{$key}}]" value="{{$data->pump->pump}}" readonly>
                                            @if($errors->first('pump_name'))
                                                <div class="invalid-feedback">
                                                    {{ $errors->first('pump_name') }}
                                                </div>
                                            @endif
                                            <span class="help-block">{{ trans('cruds.drivewaySheet.fields.pump_helper') }}</span>
                                        </div>
                                    </td>
                                    <td>
                                        <div class="form-group small">
                                            <input type="number" class="opening form-control {{ $errors->has('opening_balance') ? 'is-invalid' : ''}}" name="opening_balance[{{$key}}]" value="{{ old('opening_balance[$key]',$data->opening_balance) }}" min="0" step="0.01" readonly>
                                            @if($errors->first('opening_balance'))
                                                <div class="invalid-feedback">
                                                    {{ $errors->first('opening_balance') }}
                                                </div>
                                            @endif
                                            <span class="help-block">{{ trans('cruds.drivewaySheet.fields.opening_balance') }}</span>
                                        </div>
                                    </td>
                                    <td>
                                        <div class="form-group small">
                                            <input type="number" class="closing form-control {{ $errors->has('closing_balance') ? 'is-invalid' : ''}}" name="closing_balance[{{$key}}]" value="{{ old('closing_balance[$key]',$data->closing_balance) }}" min="0" step="0.01" read>
                                            @if($errors->first('closing_balance'))
                                                <div class="invalid-feedback">
                                                    {{ $errors->first('closing_balance') }}
                                                </div>
                                            @endif
                                            <span class="help-block">{{ trans('cruds.drivewaySheet.fields.closing_balance') }}</span>
                                        </div>
                                    </td>
                                    @foreach($fuels as $id => $fuel)
                                        <td>
                                            <div class="form-group small">
                                                <input type="text" class="form-control {{$data->fuel_id == $id ? 'stock' : null}} {{ $errors->has('fuel_id') ? 'is-invalid' : ''}}" name="fuel_type[{{$key}}]" value="{{$data->fuel_id == $id ? old('fuel_type[$key]',$data->stock) : null}}" readonly>
                                                @if($errors->first('fuel_id'))
                                                    <div class="invalid-feedback">
                                                        {{ $errors->first('fuel_id') }}
                                                    </div>
                                                @endif
                                            </div>
                                        </td>
                                    @endforeach
                                    <!-- @if($auth->is_admin == 1 && $data->is_approved == 0)
                                        <td> 
                                            <a class="btn btn-xs btn-primary" href="{{ route('admin.driveway-sheets.balance', $data->id) }}">
                                                <i class="la la-edit"></i>
                                            </a>
                                        </td>
                                    @endif -->
                                </tr>
                            @endforeach
                            <tr>   
                                <td colspan="3"><b>{{ trans('cruds.fuelStock.fields.computer_sale') }}</b></td>
                                @foreach($fuellist as $id => $fuel)                                                         
                                    <td>
                                        <div class="form-group small">
                                            <input type="number" class="form-control {{ $errors->has('computer_sale') ? 'is-invalid' : ''}}" name="computer_sale[]" value="{{ old('computer_sale[]', isset($fuel->id) ? $fuel->sale : '') }}" min="0" step="0.01">
                                            @if($errors->first('computer_sale'))
                                                <div class="invalid-feedback">
                                                    {{ $errors->first('computer_sale') }}
                                                </div>
                                            @endif
                                            <span class="help-block">{{ trans('cruds.fuelStock.fields.sale_helper') }}</span>
                                        </div>
                                    </td>
                                @endforeach
                               <!--  @if($auth->is_admin == 1)
                                <td></td>
                                @endif -->
                            </tr>
                        </tbody>
                    </table>
                    <div class="card-header"> 
                        <u>{{ trans('global.edit') }} {{ trans('cruds.fuelStock.title_singular') }}</u>
                    </div>
                    <table id="custom_table1" class="table table-bordered">
                        <thead>
                            <th>{{ trans('global.title') }}</th>
                            <th>{{ trans('cruds.fuelStock.fields.opening_stock') }}</th>
                            <th>{{ trans('cruds.fuelStock.fields.purchase') }}</th>
                            <th>{{ trans('cruds.fuelStock.fields.calculated_stock') }}</th>
                            <th>{{ trans('cruds.fuelStock.fields.closing_dips') }}</th>
                        </thead>
                        <tbody>
                            @foreach($fuellist as $key => $data)
                                <tr class="fuel-stock">
                                     <td>  
                                        <input type="hidden" name="fuel_stock_id[]" value="{{isset($data->id) ? $data->id : ''}}" readonly>
                                        <input type="hidden" name="fuel_stock[]" value="{{isset($data->id) ? $data->fuel_type : $key}}" readonly>
                                        <div class="form-group small">
                                            <input type="text" class="form-control {{ $errors->has('fuel_stock') ? 'is-invalid' : ''}}" value="{{isset($data->id) ? $data->fuel->fuel_name : $data}}" readonly required>
                                        </div>
                                    </td>       
                                    <td>
                                        <div class="form-group small">
                                            <input type="number" class="opening-stock form-control {{ $errors->has('opening_stock') ? 'is-invalid' : ''}}" name="opening_stock[]" value="{{ old('opening_stock[$key]',isset($data->id) ? $data->opening_stock : '') }}" min="0" step="0.01"  readonly required>
                                            @if($errors->first('opening_stock'))
                                                <div class="invalid-feedback">
                                                    {{ $errors->first('opening_stock') }}
                                                </div>
                                            @endif
                                            <span class="help-block">{{ trans('cruds.fuelStock.fields.opening_stock_helper') }}</span>
                                        </div>
                                    </td>                                    
                                    <td>
                                        <div class="form-group small">
                                            <input type="number" class="purchase form-control {{ $errors->has('purchase') ? 'is-invalid' : ''}}" name="purchase[]" value="{{ old('purchase[$key]',isset($data->id) ? $data->purchase : '') }}" min="0" step="0.01">
                                            @if($errors->first('purchase'))
                                                <div class="invalid-feedback">
                                                    {{ $errors->first('purchase') }}
                                                </div>
                                            @endif
                                            <span class="help-block">{{ trans('cruds.fuelStock.fields.purchase_helper') }}</span>
                                        </div>
                                    </td>
                                    <td>
                                        <div class="form-group small">
                                            <input type="number" class="calculated-stock form-control {{ $errors->has('calculated_stock') ? 'is-invalid' : ''}}" name="calculated_stock[]" value="{{ old('calculated_stock[$key]',isset($data->id) ? $data->stock : '') }}" min="0" step="0.01" readonly required>
                                            @if($errors->first('calculated_stock'))
                                                <div class="invalid-feedback">
                                                    {{ $errors->first('calculated_stock') }}
                                                </div>
                                            @endif
                                            <span class="help-block">{{ trans('cruds.fuelStock.fields.calculated_stock_helper') }}</span>
                                        </div>
                                    </td>
                                    <td>
                                        <div class="form-group small">
                                            <input type="number" class="form-control {{ $errors->has('closing_dips') ? 'is-invalid' : ''}}" name="closing_dips[]" value="{{ old('closing_dips[$key]',isset($data->id) ? $data->closing_dips : '') }}" min="0" step="0.01" required>
                                            @if($errors->first('closing_dips'))
                                                <div class="invalid-feedback">
                                                    {{ $errors->first('closing_dips') }}
                                                </div>
                                            @endif
                                            <span class="help-block">{{ trans('cruds.fuelStock.fields.closing_dips_helper') }}</span>
                                        </div>
                                    </td>
                                </tr>
                            @endforeach
                        </tbody>
                    </table>
                    <!-- Save Button -->
                    <div class="form-group small">
                        {{-- <button class="btn btn-info" type="reset">
                            {{ trans('global.reset') }}
                        </button> --}}
                        <button class="btn btn-primary add-btn" type="submit">
                            {{ trans('global.save') }}
                        </button>
                    </div>
                </form>
            </div>
        </div>
    </div>
</div>

@endsection
@section('scripts')
<script>
    'use Strict';
    $(document).ready(function () {
        $('.driveway-stock').on('input', function (event) {
            let Num1 = Number($(this).find('.opening').val());
            let Num2 = Number($(this).find('.closing').val());
            // let amount = parseFloat($('#price').val());
            if ((Num2 !=0) && (Num1 !=0)) {
                var result = (Num2 - Num1).toFixed(2);
                $(this).find('.stock').val(result);
                $(this).find('.stock-value').val(result);
            }
        });
        $('.fuel-stock').on('input', function (event) {
            let Num1 = Number($(this).find('.opening-stock').val());
            let Num2 = Number($(this).find('.purchase').val());
            // let amount = parseFloat($('#price').val());
            var result = (Num2 + Num1).toFixed(2);
            $(this).find('.calculated-stock').val(result);
        });
    });

</script>
@endsection
