@extends('layouts.admin')
@section('content')
<div class="page-wrapper">
    <div class="content container-fluid">
        <div class="page-header">
            <div class="row align-items-center">
                <div class="col">
                    <h3 class="page-title">{{trans('cruds.paymentAdvice.title_singular')}}</h3>
                    <ul class="breadcrumb">
                        <li class="breadcrumb-item"><a href="{{route('admin.home')}}">{{trans('global.dashboard') }}</a></li>
                        <li class="breadcrumb-item"><a href="{{route('admin.payment-advices.index')}}">{{trans('cruds.paymentAdvice.title') }}</a></li>
                        <li class="breadcrumb-item active">{{trans('global.add')}}</li>
                    </ul>
                </div>
                <div class="col-auto float-right ml-auto">
                    <a href="{{ route('admin.payment-advices.index') }}" class="btn add-btn"> <i class="la la-arrow-left"></i> {{ trans('global.back') }}</a>
                </div>
            </div>
        </div>
        <div class="card">
            <div class="card-header">
                {{ trans('global.create') }} {{ trans('cruds.paymentAdvice.title_singular') }}
            </div>

            <div class="card-body">
                <form method="POST" action="{{ route("admin.payment-advices.store") }}" enctype="multipart/form-data" id="payment_advice_form">
                    @csrf
                    <div class="row">
                        <div class="col-lg-4">
                            <div class="form-group">
                               <label for="date">{{ trans('cruds.paymentAdvice.fields.date') }}</label>
                               <input type="text" name="date" id="date" class="form-control date {{$errors->has('date')? 'is-invalid':''}}" required>
                               @if ($errors->first('date'))
                                   <div class="invalid-feedback">
                                       {{$errors->first('date')}}
                                   </div>
                               @endif
                           </div>
                        </div>
                        <div class="col-lg-12">
                            <table class="table table-bordered" id="field_container">
                                <tr>
                                    <th>
                                        {{ trans('cruds.paymentAdvice.fields.invoice_no') }}
                                    </th>
                                    <th>
                                        {{ trans('cruds.paymentAdvice.fields.d_note_no') }}
                                    </th>
                                    <th>
                                        {{ trans('cruds.paymentAdvice.fields.product') }}
                                    </th>
                                    <th>
                                        {{ trans('cruds.paymentAdvice.fields.r_quantity') }}
                                    </th>
                                    <th></th>
                                </tr>
                                <tr id="copy_content">
                                    <td>
                                        <div class="form-group small">
                                            <input type="text" class="form-control {{ $errors->has('invoice_no.*') ? 'is-invalid' : ''}}" id="invoice_no" name="invoice_no[0]" value="{{ old('invoice_no[0]') }}">
                                            @if($errors->first('invoice_no.*'))
                                                <div class="invalid-feedback">
                                                    {{ $errors->first('invoice_no.*') }}
                                                </div>
                                            @endif
                                            <span class="help-block">{{ trans('cruds.paymentAdvice.fields.invoice_no_helper') }}</span>
                                        </div>
                                    </td>
                                    <td>
                                        <div class="form-group small">
                                            <input type="text" class="form-control {{ $errors->has('d_note_no.*') ? 'is-invalid' : ''}}" id="d_note_no" name="d_note_no[0]" value="{{ old('d_note_no[0]') }}">
                                            @if($errors->first('d_note_no.*'))
                                                <div class="invalid-feedback">
                                                    {{ $errors->first('d_note_no.*') }}
                                                </div>
                                            @endif
                                            <span class="help-block">{{ trans('cruds.paymentAdvice.fields.d_note_no_helper') }}</span>
                                        </div>
                                    </td>
                                    <td>
                                        <div class="form-group small">
                                            <select class="form-control {{ $errors->has('product.*') ? 'is-invalid' : ''}}" id="product" name="product[0]">
                                            @foreach ($fuels as $key => $value)
                                                <option value="{{$key}}">{{$value}}</option>
                                            @endforeach
                                            </select>
                                            @if($errors->first('product.*'))
                                                <div class="invalid-feedback">
                                                    {{ $errors->first('product.*') }}
                                                </div>
                                            @endif
                                            <span class="help-block">{{ trans('cruds.paymentAdvice.fields.invoice_no_helper') }}</span>
                                        </div>
                                    </td>
                                    <td>
                                        <div class="form-group small">
                                            <input type="number" step="1" class="form-control {{ $errors->has('r_quantity.*') ? 'is-invalid' : ''}}" id="r_quantity" name="r_quantity[0]" value="{{ old('r_quantity[0]') }}">
                                            @if($errors->first('r_quantity.*'))
                                                <div class="invalid-feedback">
                                                    {{ $errors->first('r_quantity.*') }}
                                                </div>
                                            @endif
                                            <span class="help-block">{{ trans('cruds.paymentAdvice.fields.r_quantity_helper') }}</span>
                                        </div>
                                    </td>
                                    <td><a href="#" class="btn btn-xs btn-danger d-none" id="remove"><i class="fa fa-trash"></i></a></td>
                                </tr>
                            </table>
                            <div class="row my-3">
                                <div class="col-lg-12 text-center">
                                    <button class="btn btn-block btn-light" id="add_row">Add Row</button>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-lg-12">
                                    <div class="form-group">
                                        <button class="btn btn-info" type="reset">
                                            {{ trans('global.reset') }}
                                        </button>
                                        <button class="btn btn-primary" id="btn_submit" type="submit">
                                            {{ trans('global.save') }}
                                        </button>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </form>
            </div>
        </div>
    </div>
</div>
@endsection
@section('scripts')
    <script>
        $(document).ready(function(){
            var max = 15;
           var x=0;

            $('#add_row').click(function (e) {
                e.preventDefault();
                if(x < max)
                {
                    x++;
                    var clone_ele = $('#copy_content').clone();
                    clone_ele.find('#remove').removeClass('d-none');
                    clone_ele.find(':input').each(function(){
                        this.value = '';
                        this.id = this.id + '-' + x;
                        this.name = this.name.replace(/\[[0-9]\]+/, '[' + x + ']');
                    });
                    clone_ele.appendTo('#field_container');
                }
            });
            $('#field_container').on('click','#remove',function (e) {
                e.preventDefault();
                $(this).closest('tr').remove();
            });
            var i = 0;
            $('#payment_advice_form').on("submit",function (e) {
                e.preventDefault();
                $("#btn_submit").prop('disabled', true);
               $.ajax({
                   type: this.method,
                   url: this.action,
                   data:new FormData(this),
                   dataType:'JSON',
                   contentType: false,
                   cache: false,
                   processData: false,
                   beforeSend: function(response){
                   },
                   success: function (response) {
                    if (response.success) {
                        toastr.success(response.message);
                        document.getElementById('payment_advice_form').reset();
                        setTimeout(function(){
                            window.location = response.url;
                        },1000);
                    }
                    $("#btn_submit").prop('disabled', false);
                   },
                   error: function(response){
                        $.each(response.responseJSON.errors, function (index, value) {
                            toastr.error(value);
                            $("#btn_submit").prop('disabled', false);
                        });
                    }
               });

            });
        });
    </script>
@endsection

