@extends('layouts.admin')
@section('content')
<div class="page-wrapper">
    <div class="content container-fluid">
        <div class="page-header">
            <div class="row align-items-center">
                <div class="col">
                    <h3 class="page-title">{{trans('cruds.paymentAdvice.title_singular')}}</h3>
                    <ul class="breadcrumb">
                        <li class="breadcrumb-item"><a href="{{route('admin.home')}}">{{trans('global.dashboard') }}</a></li>
                        <li class="breadcrumb-item active">{{trans('cruds.paymentAdvice.title')}}</li>
                    </ul>
                </div>
                @can('payment_advice_create')
                    <div class="col-auto float-right ml-auto">
                        <a href="{{ route('admin.payment-advices.create') }}" class="btn add-btn"> <i class="fa fa-plus"></i> {{ trans('cruds.paymentAdvice.title_singular') }}</a>
                    </div>
                @endcan
            </div>
        </div>
        <div class="card">
            <div class="card-header">
                {{ trans('cruds.paymentAdvice.title_singular') }} {{ trans('global.list') }}
            </div>

            <div class="card-body">
              <div class="row filter-row">
                  <div class="col-sm-3 col-md-3">
                    <div class="form-group form-focus">
                      <div class="cal-icon">
                        <input class="form-control floating date" name="min_date" type="text">
                      </div>
                      <label class="focus-label">From</label>
                    </div>
                  </div>
                  <div class="col-sm-3 col-md-3">
                    <div class="form-group form-focus">
                      <div class="cal-icon">
                        <input class="form-control floating date" name="max_date" type="text">
                      </div>
                      <label class="focus-label">To</label>
                    </div>
                  </div>
                  <div class="col-sm-2 col-md-2">
                    <a href="#" class="btn btn-success search-btn"> Search </a>
                    <a class="btn btn-info" href="{{ route('admin.payment-advices.index') }}">Reset</a>
                  </div>
                </div>
                <div class="table-responsive">
                    <table class=" table table-bordered table-hover datatable datatable-PaymentAdvice">
                        <thead>
                            <tr>
                                <th width="10">

                                </th>
                                <th>
                                    {{__('ID')}}
                                </th>
                                <th>
                                    {{ trans('cruds.paymentAdvice.fields.date') }}
                                </th>
                                <th>
                                    {{ trans('cruds.paymentAdvice.fields.invoice_no') }}
                                </th>
                                <th>
                                    {{ trans('cruds.paymentAdvice.fields.d_note_no') }}
                                </th>
                                <th>
                                    {{ trans('cruds.paymentAdvice.fields.product') }}
                                </th>
                                <th>
                                    {{ trans('cruds.paymentAdvice.fields.r_quantity') }}
                                </th>
                                <th>
                                    {{ trans('cruds.paymentAdvice.fields.price') }}
                                </th>
                                <th>
                                    {{ trans('cruds.paymentAdvice.fields.amount') }}
                                </th>
                                <th>
                                    &nbsp;
                                </th>
                            </tr>
                        </thead>
                    </table>
                </div>
            </div>
        </div>
    </div>
</div>



@endsection
@section('scripts')
@parent
<script>
    $(function () {
        let dtButtons = $.extend(true, [], $.fn.dataTable.defaults.buttons)
        @can('payment_advice_delete')
        let deleteButtonTrans = '{{ trans('global.datatables.delete') }}'
        let deleteButton = {
            text: deleteButtonTrans,
            url: "{{ route('admin.payment-advices.massDestroy') }}",
            className: 'bg-inverse-danger',
            action: function (e, dt, node, config) {
            var ids = $.map(dt.rows({ selected: true }).nodes(), function (entry) {
                return $(entry).attr('id')
            });

            if (ids.length === 0) {
                alert('{{ trans('global.datatables.zero_selected') }}')

                return
            }

            if (confirm('{{ trans('global.areYouSure') }}')) {
                $.ajax({
                headers: {'x-csrf-token': _token},
                method: 'POST',
                url: config.url,
                data: { ids: ids, _method: 'DELETE' }})
                .done(function () { location.reload() })
            }
            }
        }
        dtButtons.push(deleteButton)
        @endcan

        let dtOverrideGlobals = {
            buttons: dtButtons,
            processing: true,
            serverSide: true,
            retrieve: true,
            aaSorting: [],
            ajax: {
            url: "{{ route('admin.payment-advices.index') }}",
                data: function(d) {
                    d.min = $('input[name=min_date]').val();
                    d.max = $('input[name=max_date]').val();
                }
            },
            columns: [
                { data: 'placeholder', name: 'placeholder',searchable:false,orderable:false},
                {data: 'DT_RowIndex', name: 'DT_RowIndex',searchable:false,orderable:false},
                { data: 'date', name: 'date' },
                { data: 'invoice', name: 'invoice' },
                { data: 'd_note_no', name: 'd_note_no' },
                { data: 'product', name: 'product' },
                { data: 'r_quantity', name: 'r_quantity' },
                { data: 'price', name: 'price' },
                { data: 'amount', name: 'amount' },
                { data: 'actions', name: '{{ trans('global.actions') }}' }
            ],
            orderCellsTop: true,
            order: [[ 0, 'desc' ]],
            pageLength: 100,
        };
        let table = $('.datatable-PaymentAdvice').DataTable(dtOverrideGlobals);
        $('a[data-toggle="tab"]').on('shown.bs.tab click', function(e){
            $($.fn.dataTable.tables(true)).DataTable()
                .columns.adjust();
        });

        // Event listener to the two range filtering inputs to redraw on input
        $('.search-btn').on("click", function(e) {
            e.preventDefault();
            $('input[name=min_date]').attr('required',true);
            $('input[name=max_date]').attr('required',true);
            if($('input[name=min_date]').val() != '' && $('input[name=max_date]').val() != ''){
                table.draw();
            }
            else{
                toastr.error('Min & Max date both are required.');
            }
        });
    });

</script>
@endsection
