@extends('layouts.admin')
@section('content')
<div class="page-wrapper">
    <div class="content container-fluid">
        <div class="page-header">
            <div class="row align-items-center">
                <div class="col">
                    <h3 class="page-title">{{trans('cruds.sale.title_singular')}}</h3>
                    <ul class="breadcrumb">
                        <li class="breadcrumb-item"><a href="{{route('admin.home')}}">{{trans('global.dashboard') }}</a></li>
                        <li class="breadcrumb-item"><a href="{{route('admin.sales.index')}}">{{trans('cruds.sale.title_singular') }}</a></li>
                        <li class="breadcrumb-item active">{{trans('global.edit')}}</li>
                    </ul>
                </div>
                <div class="col-auto float-right ml-auto">
                    <a href="{{ url('admin/sales?date='.$sale->date) }}" class="btn add-btn"> <i class="la la-arrow-left"></i>{{ trans('global.back') }}</a>
                </div>
            </div>
        </div>
        <div class="card">
            <div class="card-header">
                {{ trans('global.edit') }} {{ trans('cruds.sale.title') }}
            </div>

            <div class="card-body">
                <form method="POST" action="{{ route("admin.sales.update",[$sale->id]) }}" enctype="multipart/form-data">
                    @method('PUT')
                    @csrf
                    <div class="row">
                        <div class="col-lg-4">
                            <div class="form-group">
                                <label class="required" for="date">{{ trans('cruds.sale.fields.date') }}</label>
                                <input class="form-control date {{ $errors->has('date') ? 'is-invalid' : '' }}" type="text" name="date"  value="{{ old('date', date('d/m/Y',strtotime($sale->date))) }}" required>
                                @if($errors->has('date'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('date') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.sale.fields.date_helper') }}</span>
                            </div>
                        </div>
                        <!-- <div class="col-lg-4">
                            <div class="form-group">
                                <label class="required" for="title">{{ trans('cruds.sale.fields.title') }}</label>
                                <input class="form-control {{ $errors->has('title') ? 'is-invalid' : '' }}" type="text" name="title"  value="{{ old('title', $sale->title) }}" required>
                                @if($errors->has('title'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('title') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.sale.fields.title_helper') }}</span>
                            </div>
                        </div> -->
                        <div class="col-lg-4">
                            <div class="form-group">
                                <label class="required" for="sub_category">{{ trans('cruds.sale.fields.sub_category') }}</label>
                                <select class="form-control {{ $errors->has('sub_category') ? 'is-invalid' : '' }}" name="sub_category" required>
                                @foreach ($subCategory as $key => $value)
                                    <option value="{{$key}}" {{$sale->sub_category_id == $key ? 'selected':''}}>{{$value}}</option>
                                @endforeach
                                </select>
                                @if($errors->has('sub_category'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('sub_category') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.sale.fields.sub_category_helper') }}</span>
                            </div>
                        </div>
                        <div class="col-lg-4">
                            <div class="form-group">
                                <label class="required" for="amount">{{ trans('cruds.sale.fields.amount') }}</label>
                                <input class="form-control {{ $errors->has('amount') ? 'is-invalid' : '' }}" type="number" min="1" step="any" name="amount"  value="{{ old('amount', $sale->amount) }}" required>
                                @if($errors->has('amount'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('amount') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.sale.fields.amount_helper') }}</span>
                            </div>
                        </div>
                        {{-- <div class="col-lg-4">
                            <div class="form-group">
                                <label class="required" for="bank_account">{{ trans('cruds.sale.fields.bank_account') }}</label>
                                <select class="form-control {{ $errors->has('bank_account') ? 'is-invalid' : '' }}" name="bank_account" required>
                                @foreach ($bankAccount as $key => $value)
                                    <option value="{{$key}}" {{$sale->bank_account_id == $key ? 'selected':''}}>{{$value}}</option>
                                @endforeach
                                </select>
                                @if($errors->has('bank_account'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('bank_account') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.sale.fields.bank_account_helper') }}</span>
                            </div>
                        </div> --}}
                        <div class="col-lg-4">
                            <div class="form-group">
                                <label for="detail">{{ trans('cruds.sale.fields.detail') }}</label>
                                <input class="form-control {{ $errors->has('detail') ? 'is-invalid' : '' }}" type="text" name="detail"  value="{{ old('detail', $sale->detail) }}">
                                @if($errors->has('detail'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('detail') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.sale.fields.detail_helper') }}</span>
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-lg-12">
                            <div class="form-group">
                                {{-- <button class="btn btn-info" type="reset">
                                    {{ trans('global.reset') }}
                                </button> --}}
                                <button class="btn btn-primary" type="submit">
                                    {{ trans('global.save') }}
                                </button>
                            </div>
                        </div>
                    </div>
                </form>
            </div>
        </div>
    </div>
</div>
@endsection
