@extends('layouts.admin')
@section('content')
<div class="page-wrapper">
    <div class="content container-fluid">
        <div class="page-header">
            <div class="row align-items-center">
                <div class="col">
                    <h3 class="page-title">{{trans('cruds.setting.socialIcon.title')}}</h3>
                    <ul class="breadcrumb">
                        <li class="breadcrumb-item"><a href="{{route('admin.home')}}">{{trans('global.dashboard') }}</a></li>
                        <li class="breadcrumb-item"><a href="{{route('admin.social.index')}}">{{trans('cruds.setting.socialIcon.title') }}</a></li>
                        <li class="breadcrumb-item active">{{trans('global.add')}}</li>
                    </ul>
                </div>
                <div class="col-auto float-right ml-auto">
                    <a href="{{ route('admin.home') }}" title="Back" class="btn add-btn"> <i class="la la-arrow-left"></i>{{ trans('global.back') }}</a>
                </div>
            </div>
        </div>
        <!-- Start Contentbar -->
        <div class="contentbar">
            <div class="row add-form {{\Request::is('admin/setting/social') ? 'hide-block' : ''}}">
                <div class="col-lg-12">
                    <div class="card m-b-30">
                        <div class="card-body">
                            {{-- <div class="close-sign"><a href="#" class="btn btn-info btn-xs pull-right" id="hide"><i class="fa fa-close"></i></a></div> --}}
                            @if(isset($social))
                            <h5 class="card-title">{{ __("Edit Social Icon")}}</h5>
                            {!! Form::model($social, ['method' => 'PATCH', 'route' => ['admin.social.update', $social->id]]) !!}
                            @else
                            <h5 class="card-title">{{ __("Add Social Icon")}}</h5>
                            {!! Form::open(['method' => 'POST', 'route' => 'admin.social.store']) !!}
                            @endif
                            <div class="row">
                                <div class="col-lg-5">
                                    <div class="form-group{{ $errors->has('title') ? ' has-error' : '' }}">
                                        {!! Form::label('title', 'Social Title') !!}
                                        {!! Form::text('title', null, ['class' => 'form-control']) !!}
                                        <small class="text-danger">{{ $errors->first('title') }}</small>
                                    </div>
                                </div>
                                <div class="col-lg-5">
                                    <div class="form-group{{ $errors->has('icon') ? ' has-error' : '' }} currency-symbol-block">
                                        {!! Form::label('icon', 'Social Symbol') !!}
                                        <p class="inline info">{{ __("- Please select social symbol")}}</p>
                                        <div class="input-group">
                                            {!! Form::text('icon', null, ['class' => 'form-control social-icon-picker','autocomplete' => 'off']) !!}
                                            <span class="input-group-addon simple-input"><i class="glyphicon glyphicon-user"></i></span>
                                        </div>
                                        <small class="text-danger">{{ $errors->first('icon') }}</small>
                                    </div>
                                </div>
                                <div class="col-lg-5">
                                    <div class="form-group{{ $errors->has('url') ? ' has-error' : '' }}">
                                        {!! Form::label('url', 'Social Url') !!}
                                        {!! Form::text('url', null, ['class' => 'form-control']) !!}
                                        <small class="text-danger">{{ $errors->first('url') }}</small>
                                    </div>
                                </div>
                                <div class="col-lg-5 m-t-30">
                                    <div class="form-group{{ $errors->has('status') ? ' has-error' : '' }}">
                                        <div class="row">
                                            <div class="col-lg-6">
                                                {!! Form::label('status', 'Active status') !!}
                                            </div>
                                            <div class="col-lg-2 custom-switch">
                                                {!! Form::checkbox('status', 1, isset($settings['status']) ? $settings['status'] : 1, ['id'=>'socialstatus', 'class' => 'custom-control-input']) !!}
                                                <label class="custom-control-label" title="Status" for="socialstatus"></label>
                                            </div>
                                        </div>
                                        <small class="text-danger">{{ $errors->first('status') }}</small>
                                    </div>
                                </div>
                                <div class="col-lg-8">
                                    <div class="form-group">
                                        @if(isset($social))
                                        <button type="submit" class="btn btn-success">{{ __("Update")}}</button>
                                        @else
                                        <button type="reset" title="Reset" class="btn btn-info">{{ __("Reset")}}</button>
                                        <button type="submit" title="Create" class="btn btn-primary">{{ __("Create")}}</button>
                                        @endif
                                    </div>
                                </div>
                            </div>
                            {!! Form::close() !!}
                        </div>
                    </div>
                </div>
            </div>
            <div class="row">
                <div class="col-lg-12">
                    <div class="card m-b-30">
                        <div class="card-header">
                            <h5 class="card-title mb-0">{{ __("All Social Icons")}}</h5>
                        </div>
                        <div class="card-body">
                            <div class="table-responsive">
                                <table id="datatable-buttons" class="table table-borderless">
                                    <thead>
                                        <tr>
                                            <th>
                                            {{ __("#")}}</th>
                                            <th>{{ __("Social Name")}}</th>
                                            <th>{{ __("Social Icon")}}</th>
                                            <th>{{ __("Social Url")}}</th>
                                            <th>{{ __("Status")}}</th>
                                            <th>{{ __("Actions")}}</th>
                                        </tr>
                                    </thead>
                                    @if ($all_social)
                                    <tbody>
                                        @foreach ($all_social as $key => $item)
                                        <tr>
                                            <td>
                                                {{ filter_var($key+1)}}
                                            </td>
                                            <td>{{ filter_var($item->title)}}</td>
                                            <td><i class="{{ filter_var($item->icon)}}"></i></td>
                                            <td>{{ filter_var($item->url)}}</td>
                                            <td>
                                                @can('socialicon-edit')
                                                {!! Form::open(['method' => 'POST', 'route' => ['social.status', $item->id]]) !!}
                                                <div class="custom-switch">
                                                    {!! Form::checkbox('status', 1, $item->status == 1 ? 1 : 0, ['id' => 'switch'.$item->id, 'class' => 'custom-control-input', 'onChange'=>"this.form.submit()"]) !!}
                                                    <label class="custom-control-label" for="switch{{$item->id}}"></label>
                                                </div>
                                                {!! Form::close() !!}
                                                @else
                                                @if($item->status == 1)
                                                <span class="badge badge-success-inverse">{{ __("Active")}}</span>
                                                @else
                                                <span class="badge badge-info-inverse">{{ __("Inactive")}}</span>
                                                @endif
                                                @endcan
                                            </td>
                                            <td>
                                                <div class="button-list">
                                                    @can('socialicon-edit')
                                                    <a href="{{route('social.edit', $item->id)}}" class="btn btn-xs btn-success-rgba"><i class="feather icon-edit-2"></i></a>
                                                    @endcan
                                                    @can('socialicon-delete')
                                                    <button type="button" class="btn btn-xs btn-danger-rgba" data-toggle="modal" data-target="#deleteModal{{$item->id}}"><i class="feather icon-trash"></i></button>
                                                    <!-- Modal -->
                                                    <div id="deleteModal{{$item->id}}" class="delete-modal modal fade" role="dialog">
                                                        <div class="modal-dialog modal-sm">
                                                            <div class="modal-content">
                                                                <div class="modal-header">
                                                                    <button type="button" class="close" data-dismiss="modal">&times;</button>
                                                                    <div class="delete-icon"></div>
                                                                </div>
                                                                <div class="modal-body text-center">
                                                                    <h4 class="modal-heading">{{ __("Are You Sure ?")}}</h4>
                                                                    <p>{{ __("Do you really want to delete these records? This process cannot be undone.")}}</p>
                                                                </div>
                                                                <div class="modal-footer">
                                                                    {!! Form::open(['method' => 'DELETE', 'route' => ['social.destroy', $item->id]]) !!}
                                                                    <button type="reset" class="btn btn-dark" data-dismiss="modal">{{ __("No")}}</button>
                                                                    <button type="submit" class="btn btn-danger">{{ __("Yes")}}</button>
                                                                    {!! Form::close() !!}
                                                                </div>
                                                            </div>
                                                        </div>
                                                    </div>
                                                    @endcan
                                                </div>
                                            </td>
                                        </tr>
                                        @endforeach
                                    </tbody>
                                    @endif
                                </table>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
@endsection
