@extends('layouts.admin')
@section('content')
<div class="page-wrapper">
    <div class="content container-fluid">
        <div class="page-header">
            <div class="row align-items-center">
                <div class="col">
                    <h3 class="page-title">{{trans('cruds.sheelCard.title_singular')}}</h3>
                    <ul class="breadcrumb">
                        <li class="breadcrumb-item"><a href="{{route('admin.home')}}">{{trans('global.dashboard') }}</a></li>
                        <li class="breadcrumb-item"><a href="{{route('admin.speed-points.index')}}">{{trans('cruds.sheelCard.title') }}</a></li>
                        <li class="breadcrumb-item active">{{trans('global.add')}}</li>
                    </ul>
                </div>
                <div class="col-auto float-right ml-auto">
                    <a href="{{ route('admin.sheel-cards.index') }}" class="btn add-btn"> <i class="la la-arrow-left"></i>{{ trans('global.back') }}</a>
                </div>
            </div>
        </div>
        <div class="card">
            <div class="card-header">
                {{ trans('global.add') }} {{ trans('cruds.sheelCard.title_singular') }}
            </div>

            <div class="card-body">
                <form method="POST" action="{{ route("admin.sheel-cards.store") }}" enctype="multipart/form-data" id="shell_card_form">
                    @csrf
                    <div class="row">
                        <div class="col-lg-4">
                            <div class="form-group">
                                <label class="required" for="date">{{ trans('cruds.sheelCard.fields.date') }}</label>
                                <input class="form-control date {{ $errors->has('date') ? 'is-invalid' : '' }}" type="text" name="date" id="date" value="{{ date('d/m/Y') }}" required>
                                @if($errors->has('date'))
                                <div class="invalid-feedback">
                                    {{ $errors->first('date') }}
                                </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.sheelCard.fields.date_helper') }}</span>
                            </div>
                        </div>
                        <div class="col-lg-4">
                            <div class="form-group">
                                <label class="required" for="type">{{ trans('cruds.sheelCard.fields.type') }}</label>
                                <select class="form-control {{ $errors->has('type') ? 'is-invalid' : '' }}" name="type" id="type" required>
                                <option value="Shell Card 1">Sheel Card 1</option>
                                <option value="Shell Card 2">Sheel Card 2</option>
                                </select>
                                @if($errors->has('type'))
                                <div class="invalid-feedback">
                                    {{ $errors->first('type') }}
                                </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.sheelCard.fields.type_helper') }}</span>
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-lg-12">
                            <table class="table table-bordered" id="field_container">
                                <tr>
                                    <th>{{ trans('cruds.sheelCard.fields.ticket_no') }}</th>
                                    <th>{{ trans('cruds.sheelCard.fields.card_no') }}</th>
                                    @foreach ($fuel as $key => $value)
                                        <th>{{$value}}</th>
                                    @endforeach
                                    {{-- <th>{{ trans('cruds.sheelCard.fields.shift_no') }}</th>
                                    <th>{{ trans('cruds.sheelCard.fields.daily_total') }}</th> --}}
                                </tr>
                                <tr id="copy_content">
                                    <td>
                                        <div class="form-group small">
                                            <input type="text" name="ticket_no[0]" class="form-control">
                                        </div>
                                    </td>
                                    <td>
                                        <div class="form-group small">
                                            <input type="text" name="card_no[0]" class="form-control">
                                        </div>
                                    </td>
                                    @foreach ($fuel as $key => $value)
                                        <td>
                                            <div class="form-group small">
                                                <input type="text" name="fuel[0][{{$key}}]" class="form-control">
                                            </div>
                                        </td>
                                    @endforeach
                                    {{-- <td>
                                        <div class="form-group small">
                                            <input type="text" name="shift_total[0]" class="form-control">
                                        </div>
                                    </td>
                                    <td>
                                        <div class="form-group small">
                                            <input type="text" name="daily_total[0]" class="form-control">
                                        </div>
                                    </td> --}}
                                    <td><a href="#" class="btn btn-xs btn-danger d-none" id="remove"><i class="fa fa-trash"></i></a></td>
                                </tr>
                            </table>
                            <div class="row my-3">
                                <div class="col-lg-12 text-center">
                                    <button class="btn btn-block btn-light" id="add_row">Add Row</button>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-lg-12">
                                    <div class="form-group">
                                        <button class="btn btn-info" type="reset">
                                            {{ trans('global.reset') }}
                                        </button>
                                        <button class="btn btn-primary" id="btn_submit" type="submit">
                                            {{ trans('global.save') }}
                                        </button>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </form>
            </div>
        </div>
    </div>
</div>

@endsection
@section('scripts')
    <script>
        $(document).ready(function(){
            var max = 15;
           var x=0;

            $('#add_row').click(function (e) {
                e.preventDefault();
                if(x < max)
                {
                $('#error').addClass('d-none');
                $('#error').text('');
                    x++;
                    var clone_ele = $('#copy_content').clone();
                    clone_ele.find('#remove').removeClass('d-none');
                    clone_ele.find(':input').each(function(){
                        this.value = '';
                        this.id = this.id + '-' + x;
                        this.name = this.name.replace(/\[[0-9]\]+/, '[' + x + ']');
                    });
                    clone_ele.appendTo('#field_container');
                }
            });


            $('#field_container').on('click','#remove',function (e) {
                e.preventDefault();
                $(this).closest('tr').remove();
            });
            var i = 0;
            $('#shell_card_form').on("submit",function (e) {
                e.preventDefault();
                $("#btn_submit").prop('disabled', true);
               $.ajax({
                   type: this.method,
                   url: this.action,
                   data:new FormData(this),
                   dataType:'JSON',
                   contentType: false,
                   cache: false,
                   processData: false,
                   beforeSend: function(response){
                   },
                   success: function (response) {
                    if (response.success) {
                        toastr.success(response.message);
                        document.getElementById('shell_card_form').reset();
                        setTimeout(function(){
                            window.location = response.url;
                        },1000);
                    }
                    $("#btn_submit").prop('disabled', false);
                   },
                   error: function(response){
                        $.each(response.responseJSON.errors, function (index, value) {
                            toastr.error(value);
                            $("#btn_submit").prop('disabled', false);
                        });
                    }
               });

            });
        });
    </script>
@endsection
