@extends('layouts.admin')
@section('content')
<div class="page-wrapper">
    <div class="content container-fluid">
        <div class="page-header">
            <div class="row align-items-center">
                <div class="col">
                    <h3 class="page-title">{{trans('cruds.user.title_singular')}}</h3>
                    <ul class="breadcrumb">
                        <li class="breadcrumb-item"><a href="{{route('admin.home')}}">{{trans('global.dashboard') }}</a></li>
                        <li class="breadcrumb-item"><a href="{{route('admin.users.index')}}">{{trans('cruds.user.title') }}</a></li>
                        <li class="breadcrumb-item active">{{trans('global.edit')}}</li>
                    </ul>
                </div>
                <div class="col-auto float-right ml-auto">
                    <a href="{{ route('admin.users.index') }}" class="btn add-btn"> <i class="la la-arrow-left"></i> {{ trans('global.back') }}</a>
                </div>
            </div>
        </div>
        <div class="card">
            <div class="card-header">
                {{ trans('global.edit') }} {{ trans('cruds.user.title_singular') }}
            </div>

            <div class="card-body">
                <form method="POST" action="{{ route("admin.users.update", [$user->id]) }}" enctype="multipart/form-data">
                    @method('PUT')
                    @csrf
                    <div class="row">
                        <div class="col-lg-3">
                            <div class="form-group">
                                <label class="required" for="name">{{ trans('cruds.user.fields.name') }}</label>
                                <input class="form-control {{ $errors->has('name') ? 'is-invalid' : '' }}" type="text" name="name" id="name" value="{{ old('name', $user->name) }}" required>
                                @if($errors->has('name'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('name') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.user.fields.name_helper') }}</span>
                            </div>
                        </div>
                        <div class="col-lg-3">
                            <div class="form-group">
                                <label class="required" for="email">{{ trans('cruds.user.fields.email') }}</label>
                                <input class="form-control {{ $errors->has('email') ? 'is-invalid' : '' }}" type="email" name="email" id="email" value="{{ old('email', $user->email) }}" required>
                                @if($errors->has('email'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('email') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.user.fields.email_helper') }}</span>
                            </div>
                        </div>
                        <div class="col-lg-3">
                            <div class="form-group">
                                <label class="required" for="phone">{{ trans('cruds.user.fields.phone') }}</label>
                                <input class="form-control {{ $errors->has('phone') ? 'is-invalid' : '' }}" type="text" maxlength="10" name="phone" id="phone" value="{{ old('phone', $user->phone) }}" >
                                @if($errors->has('phone'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('phone') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.user.fields.phone_helper') }}</span>
                            </div>
                        </div>
                        <div class="col-lg-3">
                            <div class="form-group">
                                <label class="required" for="dob">{{ trans('cruds.user.fields.dob') }}</label>
                                <input class="form-control floating datetimepicker {{ $errors->has('dob') ? 'is-invalid' : '' }}" type="text" name="dob" id="dob" value="{{ old('dob',date('d/m/Y',strtotime($user->dob))) }}">
                                @if($errors->has('dob'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('dob') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.user.fields.dob_helper') }}</span>
                            </div>
                        </div>
                        <div class="col-lg-3">
                            <div class="form-group">
                                <label for="gender">{{ trans('cruds.user.fields.gender') }}</label>
                                <select name="gender" id="gender" class="form-control">
                                    <option value="">Please Select</option>
                                    <option value="male" {{$user->gender == 'male' ? 'selected' : ''}}>{{__('Male')}}</option>
                                    <option value="female" {{$user->gender == 'female' ? 'selected' : ''}}>{{__('Female')}}</option>
                                    <option value="other" {{$user->gender == 'other' ? 'selected' : ''}}>{{__('Other')}}</option>
                                </select>
                            </div>
                        </div>
                        <div class="col-lg-3">
                            <div class="form-group">
                                <label class="required" for="address">{{ trans('cruds.user.fields.address') }}</label>
                                <input class="form-control {{ $errors->has('address') ? 'is-invalid' : '' }}" type="text" name="address" id="address" value="{{ old('address', $user->address) }}">
                                @if($errors->has('address'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('address') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.user.fields.address_helper') }}</span>
                            </div>
                        </div>
                        <div class="col-lg-3">
                            <div class="form-group">
                                <label class="required" for="country">{{ trans('cruds.siteReg.country') }}</label>
                                <select class="form-control select2 {{$errors->has('country')? 'is-invalid' : ''}}" name="country" id="country" value="{{old('country', $user->country)}}">
                                    <option value="">Select Country</option>
                                    @foreach ($countries as $value)
                                        <option value="{{$value->country}}" {{$value->country == $user->country ? 'selected' : ''}}> {{$value->country}} </option>
                                    @endforeach
                                </select>
                                @if($errors->has('country'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('country') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.siteReg.country_helper') }}</span>
                            </div>
                        </div>
                        <div class="col-lg-3">
                            <div class="form-group">
                                <label class="required" for="state">{{ trans('cruds.siteReg.state') }}</label>
                                <select class="form-control select2 {{$errors->has('state_id')? 'is-invalid' : ''}}" name="state_id" id="state" value="{{old('state', $user->state_id)}}">
                                    @foreach ($states as $value)
                                    <option value="{{$value->id}}" {{$user->state_id == $value->id ? 'selected' : ''}}> {{$value->name}} </option>
                                    @endforeach
                                </select>
                                @if($errors->has('state'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('state_id') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.siteReg.state_helper') }}</span>
                            </div>
                        </div>
                        <div class="col-lg-3">
                            <div class="form-group">
                                <label class="required" for="city">{{ trans('cruds.siteReg.city') }}</label>
                                <select class="form-control select2 {{$errors->has('city_id')? 'is-invalid' : ''}}" name="city_id" id="city" value="{{old('city',$user->city_id)}}">
                                    @foreach ($cities as $value)
                                    <option value="{{$value->id}}" {{$user->city_id == $value->id ? 'selected' : ''}}> {{$value->name}} </option>
                                    @endforeach
                                </select>
                                @if($errors->has('city'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('city_id') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.siteReg.city_helper') }}</span>
                            </div>
                        </div>
                        <div class="col-lg-3">
                            <div class="form-group">
                                <label class="required" for="password">{{ trans('cruds.user.fields.password') }}</label>
                                <input class="form-control {{ $errors->has('password') ? 'is-invalid' : '' }}" type="password" name="password" id="password">
                                @if($errors->has('password'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('password') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.user.fields.password_helper') }}</span>
                            </div>
                        </div>
                        <div class="col-lg-3">
                            <div class="form-group">
                                <label class="required" for="branch_id">{{ trans('cruds.siteReg.branch') }}</label>
                                <select class="form-control select2 {{ $errors->has('branch_id') ? 'is-invalid' : '' }}" name="branch_id" id="branch" required>
                                    @foreach($branches as $branch)
                                    <option value="{{ $branch->id }}" {{ old('type', $user->branch_id) ==  $branch->id ? 'selected' : '' }}>{{ $branch->name }}</option>
                                    @endforeach
                                </select>
                                @if($errors->has('branch'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('branch_id') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.siteReg.branch_helper') }}</span>
                            </div>
                        </div>
                        <div class="col-lg-3">
                            <div class="form-group">
                                <label for="profile_pic">{{ trans('cruds.user.fields.profile_pic') }}</label>
                                <input type="file" name="profile_pic" id="profile_pic">
                            </div>
                        </div>

                        <div class="col-lg-3">
                            <div class="form-group">
                                <label class="required" for="roles">{{ trans('cruds.user.fields.roles') }}</label>
                                <div style="padding-bottom: 4px">
                                    <span class="btn btn-info btn-xs select-all" style="border-radius: 0">{{ trans('global.select_all') }}</span>
                                    <span class="btn btn-info btn-xs deselect-all" style="border-radius: 0">{{ trans('global.deselect_all') }}</span>
                                </div>
                                <select class="form-control select2 {{ $errors->has('roles') ? 'is-invalid' : '' }}" name="roles[]" id="roles" multiple required>
                                    @foreach($roles as $id => $roles)
                                        <option value="{{ $id }}" {{ (in_array($id, old('roles', [])) || $user->roles->contains($id)) ? 'selected' : '' }}>{{ $roles }}</option>
                                    @endforeach
                                </select>
                                @if($errors->has('roles'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('roles') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.user.fields.roles_helper') }}</span>
                            </div>
                        </div>
                        <div class="col-lg-3">
                            <br>
                            <label class="custom-switch {{ $errors->has('approved') ? 'is-invalid' : '' }}">
                                <input type="hidden" name="approved" value="0">
                                <input id="approved" type="checkbox" name="approved" id="approved" value="1" {{ $user->approved || old('approved', 0) === 1 ? 'checked' : '' }} class="custom-control-input">
                                <label class="custom-control-label" for="approved">
                                    {{ trans('cruds.user.fields.approved') }}</label>
                            </label>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-lg-12">
                            <div class="form-group">
                                <button class="btn btn-primary" type="submit">
                                    {{ trans('global.save') }}
                                </button>
                            </div>
                        </div>
                    </div>
                </form>
            </div>
        </div>
    </div>
</div>



@endsection
