@extends('layouts.admin')
@section('content')
<div class="page-wrapper">
    <div class="content container-fluid">
        <div class="page-header">
            <div class="row align-items-center">
                <div class="col">
                    <h3 class="page-title">{{trans('cruds.vat.title')}}</h3>
                    <ul class="breadcrumb">
                        <li class="breadcrumb-item"><a href="{{route('admin.home')}}">{{trans('global.dashboard') }}</a></li>
                        <li class="breadcrumb-item"><a href="{{route('admin.vats.index')}}">{{trans('cruds.vat.title') }}</a></li>
                        <li class="breadcrumb-item active">{{trans('global.edit')}}</li>
                    </ul>
                </div>
                <div class="col-auto float-right ml-auto">
                    <a href="{{ route('admin.vats.index') }}" class="btn add-btn"> <i class="la la-arrow-left"></i>{{ trans('global.back') }}</a>
                </div>
            </div>
        </div>
        <div class="card">
            <div class="card-header">
                {{ trans('global.edit') }} {{ trans('cruds.vat.title') }}
            </div>

            <div class="card-body">
                <form method="POST" action="{{ route("admin.vats.update",[$vat->id]) }}" enctype="multipart/form-data">
                    @method('PUT')
                    @csrf
                    <div class="row">
                        <div class="col-lg-4">
                            <div class="form-group">
                                <label class="required" for="title">{{ trans('cruds.vat.fields.title') }}</label>
                                <input class="form-control {{ $errors->has('title') ? 'is-invalid' : '' }}" type="text" name="title" id="header" value="{{ old('title', $vat->title) }}" required>
                                @if($errors->has('title'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('title') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.vat.fields.title_helper') }}</span>
                            </div>
                        </div>
                        <div class="col-lg-4">
                            <div class="form-group">
                                <label class="required" for="value">{{ trans('cruds.vat.fields.value') }}</label>
                                <input class="form-control {{ $errors->has('value') ? 'is-invalid' : '' }}" type="number" step="any" name="value" id="header" value="{{ old('value', $vat->value) }}" required>
                                @if($errors->has('value'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('value') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.vat.fields.value_helper') }}</span>
                            </div>
                        </div>
                        <div class="col-lg-4">
                            <div class="form-group">
                                <label class="required" for="effective_from">{{ trans('cruds.vat.fields.eff_from') }}</label>
                                <input class="form-control date {{ $errors->has('effective_from') ? 'is-invalid' : '' }}" type="text" step="any" name="effective_from" id="eff_from" value="{{ old('effective_from', date('m/d/Y',strtotime($vat->effective_from))) }}" required>
                                @if($errors->has('effective_from'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('effective_from') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.vat.fields.eff_from_helper') }}</span>
                            </div>
                        </div>
                        <div class="col-lg-4">
                            <div class="form-group">
                                <label class="required" for="remarks">{{ trans('cruds.vat.fields.remarks') }}</label>
                                <input class="form-control {{ $errors->has('remarks') ? 'is-invalid' : '' }}" type="text" maxlength="80" name="remarks" id="remarks" value="{{ old('remarks', $vat->remarks) }}">
                                @if($errors->has('remarks'))
                                    <div class="invalid-feedback">
                                        {{ $errors->first('remarks') }}
                                    </div>
                                @endif
                                <span class="help-block">{{ trans('cruds.vat.fields.remarks_helper') }}</span>
                            </div>
                        </div>
                        <div class="col-lg-4 my-2">
                            <label class="custom-switch">
                                <input id="status" type="checkbox" {{$vat->status ? 'checked' : ''}} value="1" name="status"
                                    class="custom-control-input">
                                <label class="custom-control-label" for="status">
                                    {{ trans('cruds.vat.fields.status') }}</label>
                            </label>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-lg-12">
                            <div class="form-group">
                                {{-- <button class="btn btn-info" type="reset">
                                    {{ trans('global.reset') }}
                                </button> --}}
                                <button class="btn btn-primary" type="submit">
                                    {{ trans('global.save') }}
                                </button>
                            </div>
                        </div>
                    </div>
                </form>
            </div>
        </div>
    </div>
</div>
@endsection
